   * ******************************************************************** *
   * ******************************************************************** *
   *                                                                      *
   *               endline variable construction do file                 *
   *                                                                      *
   * ******************************************************************** *
   * ******************************************************************** *
       ** WRITTEN BY:   odbayar batmunkh
       ** Last date modified: 24 Nov 2020

global part1 1  //load raw file
global part2 1  //clean and construct variables

*************************************
*load data from raw Excel file
*replace some special characters in data
*************************************
qui if $part1{
    *import raw excel file
      import excel "$endline_dtRaw\S4P Full Casewise Data.xlsx", sheet("Sheet1") firstrow clear
   
    *selecting all string variables
      ds, has(type string)

    *replacing special characters in all strings
      foreach var of varlist `r(varlist)' {
        replace `var'=subinstr(`var', "{", "",.) 
        replace `var'=subinstr(`var', "}", "",.) 
        replace `var'=subinstr(`var', "_", "",.) 

        cap destring `var',replace
      }

    save "$endline_dtInt/endline",replace
  }

*************************************
*clean variables and 
*generating variables for analysis
*************************************
  if $part2{
    *load raw file
      use "$endline_dtInt/endline",clear

    **********************
    *household identifiers
    **********************
      rename M2 hhid
      rename A01 counthh_members
      rename J131 count_under5

    **********************
    *latrine variables
    **********************
      egen children0_17=rsum(Grid_A04_1A04 Grid_A04_2A04)
      gen count_adult= counthh_members - children0_17
      gen owns_land=M160==1
      gen jmpsan=inlist(C24,1,2,3,5,6,7,9)
      gen no_toilet=C24==0

    **********************
    **constraints to toiliet adoption
    **********************
      split F82,parse(,) destring
      gen constraint_credit=(F821==1 |  F822==1 |  F823==1 )
      gen constraint_hardware=inlist(F821,3,4) |inlist(F822,3,4) |inlist(F823,3,4) 

    **********************
    **access of household
    **********************
      rename N172 access_poblacion
      rename N173 access_freq_travel
      rename N174 access_cost_travel
      rename N171 access_mobile_phone
      gen access_has_phone=access_mobile_phone==1
      gen access_no_phone_access=access_mobile_phone==6  
      recode access_poblacion (2=0)
      recode access_mobile_phone (6=.)

    **********************
    **house characteristics
    **********************
      rename N166 hhchar_num_bedrooms
      gen hhchar_own_house=inlist(N167,1,3,4,5)
      gen hhchar_rent_house=inlist(N167,2,6,7)
      rename N162 hhchar_material_roof
      rename N163 hhchar_material_wall
      rename N164 hhchar_material_floor

    **********************
    **agricultural characteristics 
    **********************
      rename Grid_M161_1M161 agri_asset_Goat
      rename Grid_M161_2M161 agri_asset_Pig
      rename Grid_M161_3M161 agri_asset_Piglet
      rename Grid_M161_4M161 agri_asset_Cow
      rename Grid_M161_5M161 agri_asset_Carabao
      rename Grid_M161_6M161 agri_asset_Chicken
      rename Grid_M161_7M161 agri_asset_Rooster
      rename Grid_M161_8M161 agri_asset_Waterpump
      rename Grid_M161_9M161 agri_asset_Thresher
      rename Grid_M161_10M161 agri_asset_Handtractor
      rename Grid_M161_11M161 agri_asset_Irrigationequipment
      rename Grid_M161_12M161 agri_asset_Powersaw
      rename Grid_M161_13M161 agri_asset_Otherassets
      rename Grid_M161_14M161 agri_asset_Cat
      rename Grid_M161_15M161 agri_asset_Dog
      rename Grid_M161_16M161 agri_asset_Duck
      rename Grid_M161_17M161 agri_asset_Horse
      rename Grid_M161_18M161 agri_asset_Turkey
      rename M160 agri_asset_agri_land

      recode agri_asset_* (2=0)

    **********************
    **household assets
    **********************
      rename Grid_M158_1M158_Quant  hh_asset_Radio
      rename Grid_M158_2M158_Quant  hh_asset_Television
      rename Grid_M158_3M158_Quant  hh_asset_media_player
      rename Grid_M158_4M158_Quant  hh_asset_Landlinephone
      rename Grid_M158_5M158_Quant  hh_asset_Cellularphone
      rename Grid_M158_6M158_Quant  hh_asset_Personalcomputer
      rename Grid_M158_7M158_Quant  hh_asset_Washingmachine
      rename Grid_M158_8M158_Quant  hh_asset_Refrigerator
      rename Grid_M158_9M158_Quant  hh_asset_Airconditioner
      rename Grid_M158_10M158_Quant hh_asset_media_player2
      rename Grid_M158_11M158_Quant hh_asset_Karaoke
      rename Grid_M158_12M158_Quant hh_asset_Sala
      rename Grid_M158_13M158_Quant hh_asset_Dining
      rename Grid_M158_14M158_Quant hh_asset_Microwave

      recode hh_asset_* (.=0)

      rename Grid_M159_1M159_Quant hh_asset_Car
      rename Grid_M159_2M159_Quant hh_asset_Motorcycle
      rename Grid_M159_3M159_Quant hh_asset_Bicycle
      rename Grid_M159_4M159_Quant hh_asset_Animalcart
      rename Grid_M159_5M159_Quant hh_asset_Tractor
      rename Grid_M159_6M159_Quant hh_asset_banca
      rename Grid_M159_7M159_Quant hh_asset_motorbanca
      rename Grid_M159_8M159_Quant hh_asset_other
      rename Grid_M159_9M159_Quant hh_asset_Electricfan

      recode hh_asset_* (.=0)

    **********************
    **household income
    **********************
      rename L150 hh_members_work
      rename L151 hh_members_work_count 
      gen hh_is_agricultural= L152==1
      rename L153 hh_agri_income
      rename L143_C_1 hh_income_last4weeks
      replace hh_income_last4weeks=0 if L143!=1

      gen hh_is_fishing= L154==1
      rename L155 hh_fishing_income 

      rename L156 hh_members_work_family_bis
      rename L157 hh_family_bis_income 

      recode hh_members_work hh_members_work_count hh_members_work_family_bis (2=0) (9999=.) (9998=.)
      recode hh_agri_income hh_fishing_income hh_family_bis_income (9999=.) (9=.)

      rename Grid_L157_1_1L157_1 hh_income_source_Interest
      rename Grid_L157_1_2L157_1 hh_income_source_Remittances
      rename Grid_L157_1_3L157_1 hh_income_source_Rental_income
      rename Grid_L157_1_4L157_1 hh_income_source_Scholarship
      rename Grid_L157_1_5L157_1 hh_income_source_4p
      rename Grid_L157_1_6L157_1 hh_income_source_Donation_ngo
      rename Grid_L157_1_7L157_1 hh_income_source_Pension
      rename Grid_L157_1_8L157_1 hh_income_source_Other
      rename Grid_L157_1_9L157_1 hh_income_source_Salary

      recode hh_income_source_* (2=0)

    **********************
    **household head characteristics
    **********************
      gen temp_hh_head_age = year(K134)
      gen hh_head_age=2019-temp_hh_head_age

      rename K135 hh_head_gender
      rename K136 hh_head_marital_status
      rename K137 hh_head_educ
      rename K138 hh_head_occupation
      gen hh_head_is_daylaborer = hh_head_occupation==9
      gen hh_head_has_basic_literacy = hh_head_occupation==1
      gen hh_head_worked_12m = L141==1
      gen hh_head_worked_1m=L142==1
      gen hh_head_income_1m=hh_income_last4weeks
      recode hh_head_income_1m (9999=.) (9998=.)
      rename L147 hh_head_job_type
      rename L148 hh_head_job_category 
      rename L149 hh_head_payment_schedule

    **********************
    **child reported illnesses
    **********************
      rename Grid_J132_1J132  illness_Fever
      rename Grid_J132_2J132  illness_Constantcough
      rename Grid_J132_3J132  illness_Congestion
      rename Grid_J132_4J132  illness_Panting
      rename Grid_J132_5J132  illness_Stomachpain
      rename Grid_J132_6J132  illness_Nausea
      rename Grid_J132_7J132  illness_Vomiting
      rename Grid_J132_8J132  illness_Diarrhea
      rename Grid_J132_9J132  illness_3plusbowelmovements
      rename Grid_J132_10J132 illness_Waterystool
      rename Grid_J132_11J132 illness_Mucusbloodstool
      rename Grid_J132_12J132 illness_Refusedeat

    **********************
    **perception on toilet and sanitation
    **********************
      rename I129 perception_best_way_toilet  
      rename I127 perception_importance_toilet
      rename Grid_I126_1I126 perception_impor_visit 
      rename Grid_I126_2I126 perception_impor_comm_meeting 
      rename Grid_I126_3I126 perception_impor_aware 
      rename Grid_I126_4I126 perception_impor_benefits  
       
      rename Grid_I125_1I125 reported_change_hw
      rename Grid_I125_2I125 reported_change_od
      rename Grid_I125_3I125 reported_change_use_toilet
      rename Grid_I125_4I125 reported_change_safe_water_drink

      rename Grid_I124_1I124 reported_coverage_hw 
      rename Grid_I124_2I124 reported_coverage_od 
      rename Grid_I124_3I124 reported_coverage_use_toilet 
      rename Grid_I124_4I124 reported_coverage_safe_water 
        
      rename Grid_I123_1I123 reported_programs_safe_water 
      rename Grid_I123_2I123 reported_programs_sanitation
        
      recode reported_programs_* perception_impor_* (2=0) 
      rename H117 reported_quality_life

    **********************
    **toilet construction
    **********************
      rename Grid_F71_1F71 toilet_improved
      rename Grid_F71_2F71 toilet_built
      
      recode toilet_* (2=0)

      gen toilet_repair_or_built=toilet_improved==1 | toilet_built==1
      label var toilet_repair_or_built "binary for repairing or building a toilet"

      rename F73a_C_97  toilet_spent_amount_improvement
      rename F73b_C_1 toilet_spent_amount_construction
      recode toilet_spent_amount_* (.=0)

      egen toilet_amount_spent_total=rsum(toilet_spent_amount_*)
      label var toilet_amount_spent_total "total amount spent on toilet construction or improvement"

      rename F74a toilet_loan_improvement
      rename F74b toilet_loan_construction
      recode toilet_loan_* (2=0)

      gen toilet_loan_any=toilet_loan_improvement==1 | toilet_loan_construction==1
      label var toilet_loan_any "did household take any loan for toilet improvement or construction"

      rename F76a_C_1 toilet_loan_amount_improve
      rename F76b_C_1 toilet_loan_amount_constru
      recode toilet_loan_amount_* (9999=.) (9998=.)

      egen toilet_loan_total=rsum(toilet_loan_amount_improve toilet_loan_amount_constru)
      label var toilet_loan_total "total amount of loans for toilet improvement or construction"

      rename F77a toilet_subsidy_improve
      rename F77b toilet_subsidy_constru
      recode toilet_subsidy_* (2=0)
      gen toilet_subsidy_any=toilet_subsidy_improve==1 | toilet_subsidy_constru==1
      label var toilet_subsidy_any "household received subsidy from government for toilet repair or construction"

      rename F78a toilet_subsidy_amount_improve
      rename F78b toilet_subsidy_amount_constru
      recode toilet_subsidy_amount_* (9999=.) (9998=.)

      egen toilet_subsidy_total=rsum(toilet_subsidy_amount_*)
      label var toilet_subsidy_total "total amount household received in subsidies for toilet repair or construction"

      split F80,parse(,) destring
      rename F801 toilet_reason

    **********************
    **toilet characteristics
    **********************
      rename Grid_C32_1C32  toilet_feat_Raisedplatform
      rename Grid_C32_2C32  toilet_feat_Footrests
      rename Grid_C32_3C32  toilet_feat_Seat
      rename Grid_C32_4C32  toilet_feat_Floortilesconcrete
      rename Grid_C32_5C32  toilet_feat_Fullyenclosedwall
      rename Grid_C32_6C32  toilet_feat_Partenclosedwall
      rename Grid_C32_7C32  toilet_feat_Fullycoveredroof
      rename Grid_C32_8C32  toilet_feat_Partcoveredroof
      rename Grid_C32_9C32  toilet_feat_Door
      rename Grid_C32_10C32 toilet_feat_Waterseal
             
      rename C24 toilet_type
      rename C25 toilet_shared
      rename C26 toilet_location
      rename C27 toilet_const_year
      rename C28 toilet_amount_spent_alt
      rename C29 toilet_spend_source
      rename C31 toilet_has_leak
      rename C35 toilet_has_flies
      rename C36 toilet_has_hw_station
      rename C37 toilet_has_hw_soap_water
      rename C38 toilet_distance_hw_station
      label define hw_distance 1"1-10 meters or more" 2 "less than 10 meters"
      label values toilet_distance_hw_station hw_distance

      recode toilet_feat_* toilet_has_leak toilet_has_hw_station toilet_shared (2=0)
      recode toilet_has_flies (3=0) (2=1)

    **********************
    **loans and banking
    **********************
      rename Grid_E52_1E52 bank_has_bank_account 
      rename Grid_E52_2E52 bank_member_coop
      rename Grid_E52_3E52 bank_member_mfi
      recode bank_* (2=0)

      rename E56 hh_has_loans
      recode hh_has_loans (2=0)

      gen loan_for_toilet=E58==1
      rename E63_C_1 loan_amount
      recode loan_amount (9999=.) (9998=.)

    **********************
    *external support
    **********************
      rename Grid_D48_1D48 external_support_muni_brgy 
      rename Grid_D48_2D48 external_support_SL 
      rename Grid_D48_3D48 external_support_KalahiProgram 
      rename Grid_D48_4D48 external_support_25perASA 
      rename Grid_D48_5D48 external_support_50perASA
      recode external_support_* (2=0)

    **********************
    *latrine satisfaction
    **********************
      rename C39 satisfaction_toilet

    **********************
    *sanitation advice
    **********************
      gen advice_past3m=D40!="0" 

      rename D41 advice_source
      rename D42 advice_recent
      rename D43 advice_attend_fds

    **********************
    **jmp water source
    **********************
      gen jmpwater=inlist(B12a,1,2,3,4,6,8,9)
      split B12d, parse(,) destring
      gen jmpwater_drinking=inlist(B12c,1,2,3,4,6,8,9) | inlist(B12d1,1,2,3,4,6,8,9) | inlist(B12d2,1,2,3,4,6,8,9) | inlist(B12d3,1,2,3,4,6,8,9) 


    **********************
    *4p program variables
    **********************
      *fds 
        rename D44a advice_familiar_fds
        rename D45a advice_recent_fds
        rename D46a advice_facilitator_fds

      *clts
        rename D44b advice_familiar_clts
        rename D45b advice_recent_clts
        rename D46b advice_facilitator_clts
        recode advice_familiar_* (2=0)

      **4P grants
        rename A07 pppp_attendee
        rename A08 pppp_last_amount
        split A09,parse(,) destring
        forvalues x = 1/21{
          gen pppp_used_for_`x'=A091==`x' | A092==`x' | A093==`x' | A094==`x' | A095==`x' | A096==`x' | A097==`x' 
        }
      *label purpose of grants
        label var pppp_used_for_1   "4P grant used for Food "
        label var pppp_used_for_2   "4P grant used for Health"
        label var pppp_used_for_3   "4P grant used for Education"
        label var pppp_used_for_4   "4P grant used for Housing"
        label var pppp_used_for_5   "4P grant used for Clothing"
        label var pppp_used_for_6   "4P grant used for Investment"
        label var pppp_used_for_7   "4P grant used for Savings"
        label var pppp_used_for_8   "4P grant used for Coconutwine"
        label var pppp_used_for_9   "4P grant used for Eatery"
        label var pppp_used_for_10  "4P grant used for Feeds"
        label var pppp_used_for_11  "4P grant used for Native delicacies "
        label var pppp_used_for_12  "4P grant used for Piggery"
        label var pppp_used_for_13  "4P grant used for Rootcrop"
        label var pppp_used_for_14  "4P grant used for Sari-sari store"
        label var pppp_used_for_15  "4P grant used for Allowance"
        label var pppp_used_for_16  "4P grant used for Fare"
        label var pppp_used_for_17  "4P grant used for Fertilizer"
        label var pppp_used_for_18  "4P grant used for Household needs"
        label var pppp_used_for_19  "4P grant used for Loan payment"
        label var pppp_used_for_20  "4P grant used for Lot land payment"
        label var pppp_used_for_21  "4P grant used for Fee for live birth"
            
        rename A10 pppp_method

    **********************
    *constraints and sacrifies reported
    **********************
      rename F82 reported_constraint
      split reported_constraint, p(,)

      rename G83 advice_familiar_asa
      rename G97 sacrifice1
      rename G98 sacrifice2

      split sacrifice2,parse(,) destring
      recode sacrifice21 sacrifice22(999=.) 

      forvalues x=1(1)7{
        gen sac_`x'=sacrifice21==`x' | sacrifice22==`x'
      }

      label var sac_1 "We missed one or several meals"
      label var sac_2 "We reduced household spending"
      label var sac_3 "We used our savings intended for another purpose"
      label var sac_4 "Accept laundry"
      label var sac_5 "Selling fish"
      label var sac_6 "Raising hogs /pig"
      label var sac_7 "My husband applied on construction"

      rename I130 recommend
      rename D49 advice_familiar_s4p

    **survey round variable
      gen survid=2

    **********************
    *loan information
    **********************
      rename D48_1 has_asa_loan

      label var Grid_G93_1G93 "Amount of loan" 
      label var Grid_G93_2G93 "Amount of discount" 
      label var Grid_G93_3G93 "Amount of weekly payment" 
      label var Grid_G93_4G93 "Weekly mode of payment" 
      label var Grid_G93_5G93 "Payment during weekly meetings" 
      label var Grid_G93_6G93 "Loan term of 6 or 12 months " 
      label var Grid_G93_7G93 "Disbursement at the ASA branch office" 
      label var Grid_G93_8G93 "Processing of application " 
      label var Grid_G93_9G93 "Accredited masons who have to construct the toilet "

      rename G94  missed_payment                       

    *******************************
    *dropping unnecessary variables
    *******************************
      drop F82* QS Picture_YN Picture F80 F802 F803 N169_C_97 N169 N168_C_97 N168 N167 N165 N164a_C_97 N164a N164_C_97 N163a N162a M2_1 M16TXT M16T M16D M15M16_LOI L154 L152 L151_C_1 L149_C_97 L148_C_97 L146_C_1 L146 L145_C_1 L145 L144_C_1 L144 L143 L142 L141 K140 K139 K134 K133  H121 H120 H119 H118 H116 H115 H114 H113 H112 H111 H110 H108_C_97 H108 H107 H106 H104 Grid_N170_3N170 Grid_N170_2N170 Grid_N170_1N170 Grid_M161_9M161_Oth Grid_M161_8M161_Oth Grid_M161_7M161_Oth Grid_M161_6M161_Oth Grid_M161_5M161_Oth Grid_M161_4M161_Oth Grid_M161_3M161_Oth Grid_M161_2M161_Oth Grid_M161_1M161_Oth Grid_M161_18M161_Oth Grid_M161_17M161_Oth Grid_M161_16M161_Oth Grid_M161_15M161_Oth Grid_M161_14M161_Oth Grid_M161_13M161_Oth Grid_M161_12M161_Oth Grid_M161_11M161_Oth Grid_M161_10M161_Oth Grid_M159_9M159_Oth Grid_M159_9M159 Grid_M159_8M159_Oth Grid_M159_8M159 Grid_M159_7M159_Oth Grid_M159_7M159 Grid_M159_6M159_Oth Grid_M159_6M159 Grid_M159_5M159_Oth Grid_M159_5M159 Grid_M159_4M159_Oth Grid_M159_4M159 Grid_M159_3M159_Oth Grid_M159_3M159 Grid_M159_2M159_Oth Grid_M159_2M159 Grid_M159_1M159_Oth Grid_M159_1M159 Grid_M158_9M158 Grid_M158_8M158 Grid_M158_7M158 Grid_M158_6M158 Grid_M158_5M158 Grid_M158_4M158 Grid_M158_3M158 Grid_M158_2M158 Grid_M158_1M158 Grid_M158_14M158 Grid_M158_13M158 Grid_M158_12M158 Grid_M158_11M158 Grid_M158_10M158 Grid_L157_1_9L157_1_Oth Grid_L157_1_8L157_1_Oth Grid_L157_1_7L157_1_Oth Grid_L157_1_6L157_1_Oth Grid_L157_1_5L157_1_Oth Grid_L157_1_4L157_1_Oth Grid_L157_1_3L157_1_Oth Grid_L157_1_2L157_1_Oth Grid_L157_1_1L157_1_Oth Grid_I128_5I128 Grid_I128_4I128 Grid_I128_3I128 Grid_I128_2I128 Grid_I128_1I128 Grid_I122_4I122 Grid_I122_3I122 Grid_I122_2I122 Grid_I122_1I122 Grid_H109_2H109 Grid_H109_1H109 Grid_H105_3H105 Grid_H105_2H105 Grid_H105_1H105  Grid_D50_1D50 Grid_D47_2D47 Grid_D47_1D47 Grid_C32a_9C32a_Not Grid_C32a_9C32a Grid_C32a_8C32a_Not Grid_C32a_8C32a Grid_C32a_7C32a_Not Grid_C32a_7C32a Grid_C32a_6C32a_Not Grid_C32a_6C32a Grid_C32a_5C32a_Not Grid_C32a_5C32a Grid_C32a_4C32a_Not Grid_C32a_4C32a Grid_C32a_3C32a_Not Grid_C32a_3C32a Grid_C32a_2C32a_Not Grid_C32a_2C32a Grid_C32a_1C32a_Not Grid_C32a_1C32a Grid_C32a_10C32a_Not Grid_C32a_10C32a Grid_A05_3A05 Grid_A05_2A05 Grid_A05_1A05 Grid_A04_2A04 Grid_A04_1A04 G99_C_97 G99 G98_C_97 G96_C_97 G96_C_4 G96 G95  G92 G91_C_97 G91 G90_C_3 G90 G89_C_4 G89 G88 G87 G86_C_97 G86 G85 G84_C_97 G84  G103 G102_C_97 G102 G101_C_97 G101 G100_C_97 G100 F81_C_5 F81_C_4 F81 F80_C_15 F79 F78b_C_1 F78a_C_1   F75b_C_97 F75b F75a_C_97 F75a F73b F73a F72b_C_97 F72b F72a_C_97 F72a E70_C_1 E70 E69_C_1 E69 E68_C_97 E68 E67_C_5 E67 E66 E65_C_1 E65 E64 E63 E62 E61_C_11 E61 E60 E59 E58_C_1 E58 E57_C_1 E57 E55 E54_C_1 E54 E53_C_2 E53_C_1 E53 D51_CODED D51   D41_C_12 C34a_C_97 C34a C34_C_97 C34 C33a_C_97 C33a C33_C_97 C33 C32a_Intro1 C30_C_97 C30 C24_C_13 B23_C_97 B23 B22 B21_C_97 B21 B20 B19 B18 B17_C_97 B17 B16 B15 B14b_C_997 B14b B14a_C_997 B14a B13b_C_3 B13b B13a_C_3 B13a B12d3 B12d2 B12d1 B12d B12c B12b B12a A11 A10_C_4 A09_C_97 A09_C_6 A097 A096 A095 A094 A093 A092 A091 A09 A07_C_97 A06 A03 A02_1 A02

    *******************************
    *have to fix the hhids to match baseline
    *******************************
    preserve
      import excel "$endline_doc/Endline Survey Casewise Data file", firstrow clear
      rename HHNo hhid
      replace TreatmentArm=subinstr(TreatmentArm, "{", "",.) 
      replace TreatmentArm=subinstr(TreatmentArm, "}", "",.) 
      replace TreatmentArm=subinstr(TreatmentArm, "_", "",.) 
      destring TreatmentArm,replace
      tempfile hhid_fix
      save `hhid_fix'
    restore
    *adding baseline ids to endline dataset
      merge 1:1 hhid using `hhid_fix',nogen
      drop hhid
      rename BaselineNo hhid
      destring hhid,replace

    *make all variables lowercase
      tolower*

    *******************************
    *dropping unnecessary variables
    *******************************
      cap drop nscbbgycode province citymunicipality barangay treatment

    save "$endline_dtFin/endline_hh",replace
  }

//** disabled code, maybe for later

    *identifying variables that are 1 yes 2 no, then recoding those to be 1 yes 0 no
    /*
    cap log close
    log using "$endline_out\missing.log",replace

      *selecting all string variables
      ds, has(type numeric)
      local numeric "`r(varlist)'"


    foreach x of local numeric{
       qui egen max=max(`x') if survid==2
       qui egen min=min(`x') if survid==2
       *recode `x' (2=0) if max==2 & min==1
       if max==2 & min==1{
          di "`x'"
        } 
       qui drop max min
    }

    di "possible 2/1 variables: `numeric'"

    foreach x of local numeric {
       local label : variable label `x'
       di "variable `x' |`label'| "
     
       tabstat `x',by(survid) stat(mean count max min)
    }
    log close
    */
