   * ******************************************************************** *
   * ******************************************************************** *
   *                                                                      *
   *               baseline variable construction do file                 *
   *                                                                      *
   * ******************************************************************** *
   * ******************************************************************** *
       ** IDS VAR:      hhid
       ** WRITTEN BY:   odbayar batmunkh
       ** Last date modified: 24 Feb 2019

*setting path
  cd "$baseline_dtInt"

*********************
*household dataset
*********************
  *load data
    use "$baseline_dtInt/HH_Characteristics_2.12.16.dta",clear

  *harmonizing latrine categories between baseline and endline
    recode G7_1 (12=0) (8=9) (9=8) (99=.)

  **making a basic list of household variables
    gen byte JMPsan = inlist(G7_1,1,2,3,5,6,7,9)
      label define JMPsan 0 "Unimproved Sanitation" 1 "Improved Sanitation"
      label values JMPsan JMPsan
      label var JMPsan "JMP Improved Sanitation"

  **variable generation
    gen no_toilet=G7_1==0
    gen hhchar_num_bedrooms=G5_8 if inrange(G5_8,0,8)
    gen owns_land=G4_3==1

    foreach x of varlist B3_15_*{
      recode `x' (2=1) (3=1) (4=0) (98=.) (99=.)
    }

  **make all variables lowercase
    tolower *

  **variable generation
    gen constraint_credit=g7_47_1==1
    gen constraint_hardware=g7_47_3==3 | g7_47_4==4

    rename b3_15_1 Grid_L157_1_1L157_1
    rename b3_15_2 Grid_L157_1_2L157_1
    rename b3_15_3 Grid_L157_1_3L157_1
    rename b3_15_4 Grid_L157_1_4L157_1
    rename b3_15_5 Grid_L157_1_5L157_1
    rename b3_15_6 Grid_L157_1_6L157_1
    rename b3_15_7 Grid_L157_1_7L157_1
    rename b3_15_8 Grid_L157_1_8L157_1
    rename b3_15_9 Grid_L157_1_9L157_1

    rename Grid_L157_1_1L157_1 hh_income_source_Interest
    rename Grid_L157_1_2L157_1 hh_income_source_Remittances
    rename Grid_L157_1_3L157_1 hh_income_source_Rental_income
    rename Grid_L157_1_4L157_1 hh_income_source_Scholarship
    rename Grid_L157_1_5L157_1 hh_income_source_4p
    rename Grid_L157_1_6L157_1 hh_income_source_Donation_ngo
    rename Grid_L157_1_7L157_1 hh_income_source_Pension
    rename Grid_L157_1_8L157_1 hh_income_source_Other
    rename Grid_L157_1_9L157_1 hh_income_source_Salary

    recode hh_income_source_* (2=0)

  *dropping empty surveys
    drop if hhid==.

  **house characteristics
    gen hhchar_own_house=inlist(g5_2,1)
    gen hhchar_rent_house=!inlist(g5_2,1)
    rename g5_5 hhchar_material_roof
    rename g5_6 hhchar_material_wall
    rename g5_7 hhchar_material_floor
    recode hhchar_* (96=.) (98=.) (99=.)

  **agricultural characteristics 
    rename g4_6_1    agri_asset_Goat
    rename g4_6_2    agri_asset_Pig
    rename g4_6_3    agri_asset_Piglet
    rename g4_6_4    agri_asset_Cow
    rename g4_6_5    agri_asset_Carabao
    rename g4_6_6    agri_asset_Chicken
    rename g4_6_7    agri_asset_Rooster
    rename g4_6_8    agri_asset_Waterpump
    rename g4_6_9    agri_asset_Thresher
    rename g4_6_10   agri_asset_Handtractor
    rename g4_6_11   agri_asset_Irrigationequipment
    rename g4_6_12   agri_asset_Powersaw
    rename g4_6_96   agri_asset_Otherassets_temp
    rename g16_1_1   agri_asset_Cat
    rename g16_1_2   agri_asset_Dog
    rename g16_1_3   agri_asset_Duck
    rename g16_1_4   agri_asset_Horse
    rename g16_1_5   agri_asset_Turkey
    gen agri_asset_Otherassets=agri_asset_Otherassets_temp!=""
    destring agri_asset_Otherassets,replace
    drop agri_asset_Otherassets_temp
    rename g4_3 agri_asset_agri_land
    rename g4_4 agri_asset_land_area
    rename g4_5 agri_asset_land_value
           
    recode agri_asset_*  (96=.) (98=.) (99=.) (95=.) (2=0) (999999999=.) (999999997=.) (999999998=.)

  **household assets
    rename g4_1_1  hh_asset_Radio
    rename g4_1_2  hh_asset_Television
    rename g4_1_7  hh_asset_media_player
    rename g4_1_3  hh_asset_Landlinephone
    rename g4_1_4  hh_asset_Cellularphone
    rename g4_1_9  hh_asset_Personalcomputer
    rename g4_1_5  hh_asset_Washingmachine
    rename g4_1_6  hh_asset_Refrigerator
    rename g4_1_8 hh_asset_Karaoke

    recode hh_asset_* (96=.) (98=.) (99=.) (95=.) (2=0)

    rename g4_1_13 hh_asset_Car
    rename g4_1_12 hh_asset_Motorcycle
    rename g4_1_10 hh_asset_Bicycle
    rename g4_1_11 hh_asset_Animalcart
    rename g4_1_14 hh_asset_Tractor
    rename g4_1_15 hh_asset_banca
    rename g4_1_16 hh_asset_motorbanca
    rename g4_1_96 hh_asset_other_temp
    gen hh_asset_other=hh_asset_other_temp!=""
    drop hh_asset_other_temp
    destring hh_asset_other,replace

    recode hh_asset_* (96=.) (98=.) (99=.) (95=.) (2=0)

  *generating current value of all household assets for baseline balance
    recode g4_2_* (999997=.) (999998=.) (999999=.)
    egen hh_total_value_all_assets=rsum(g4_2_*)
    label var hh_total_value_all_assets "Total value of all assets of the household at baseline in PHP" 

  **perception on toilet and sanitation

    rename g7_22 toilet_under_construction
    rename g7_23_1 access_toilet_supplies1
    rename g7_24_1 access_toilet_supplies2
    rename g7_25_1 access_toilet_supplies3
    rename g7_27_1 access_toilet_supplies4

    recode toilet_under_construction (2=1) (3=0) (98=.) (99=.) 
   
    rename g7_48_1 reported_programs_safe_water 
    recode reported_programs_safe_water (.=0)
    gen reported_programs_sanitation=g7_48_2==2 | g7_48_3==3 | g7_48_4==4 | g7_48_5==5 | g7_48_6==6 | g7_48_8==8 

  **toilet construction
    gen toilet_improved=g7_30==1
    recode g7_32 g7_34 (999997=0) (999999=0) (999998=0)
    gen toilet_loan_improvement=g7_32!=0
    rename g7_32 toilet_loan_amount_improve
    rename g7_34 toilet_savings_improvement

    gen toilet_subsidy_any=g7_35==1
    label var toilet_subsidy_any "household received subsidy from government for toilet repair or construction"

    rename g7_36 toilet_subsidy_amount_improve
    recode toilet_subsidy_amount_improve (999997=0) (999999=0)

    egen toilet_subsidy_total=rsum(toilet_subsidy_amount_*)
    label var toilet_subsidy_total "total amount household received in subsidies for toilet repair or construction"

    gen toilet_reason=.

    forvalues x = 1(1)14{
      replace toilet_reason=`x' if g7_38_`x'==`x'
    }
    forvalues x = 96(1)99{
      replace toilet_reason=`x' if g7_38_`x'==`x'
    }

    recode toilet_reason (96=.) (97=.) (98=.) (99=.) 

  **toilet characteristics
    rename g7_7_1   toilet_feat_Raisedplatform
    rename g7_7_2   toilet_feat_Footrests
    rename g7_7_3   toilet_feat_Seat
    rename g7_7_4   toilet_feat_Floortilesconcrete
    rename g7_7_5   toilet_feat_Fullyenclosedwall
    rename g7_7_6   toilet_feat_Partenclosedwall
    rename g7_7_7   toilet_feat_Fullycoveredroof
    rename g7_7_8   toilet_feat_Partcoveredroof
    rename g7_7_9   toilet_feat_Door
    rename g7_7_10   toilet_feat_Waterseal

    rename g7_1 toilet_type
    rename g7_2 toilet_shared
    rename g7_4 toilet_location
    *rename C27 toilet_const_year
    rename g7_6 toilet_has_leak
    rename g7_14 toilet_has_flies

    rename g7_18 toilet_has_hw_station
    rename g7_19 toilet_has_hw_soap_water
    *rename C38 toilet_distance_hw_station
    *label define hw_distance 1"1-10 meters or more" 2 "less than 10 meters"
    *label values toilet_distance_hw_station hw_distance

    recode toilet_feat_* toilet_has_leak toilet_has_flies toilet_has_hw_station toilet_shared toilet_has_hw_soap_water ///
           (2=0) (96=.) (97=.) (98=.) (99=.) 

  *latrine satisfaction
    rename g7_21 satisfaction_toilet
    recode satisfaction_toilet (96=.) (97=.) (98=.) (99=.) 
    *recoding satisfaction variable to be , higher the better
    recode satisfaction_toilet (4=1) (3=2) (2=3) (1=4)

    label define satisfaction_label 1 "Very dissatisfied" 2 "Somewhat dissatisfied" 3 "Somewhat satisfied" 4 "Very satisfied"
    label values satisfaction_toilet satisfaction_label

  *sanitation advice
    gen advice_past3m=g7_48_7!=7
    replace advice_past3m=0 if g7_48_98==98 
    replace advice_past3m=0 if g7_48_99==99

    rename g7_49 advice_source
    rename g7_50 advice_recent
    rename g7_51 advice_attend_fds

    recode advice_source advice_recent advice_attend_fds (96=.) (97=.) (98=.) (99=.) 

  **jmp water source
    gen jmpwater=inlist(g6_1_1,1,2,3,4,6,8,9)
    gen jmpwater_drinking=jmpwater

  *************
  **4P grants
  *************
  *gen pppp_attendee=inlist(g7_51,1,2)
    rename b3_16_5 pppp_last_amount
    recode pppp_last_amount (999997=.) (999999=.)

  *survey round variable
    gen survid=1
    isid hhid

  **has loan at baseline
    gen toilet_loan_any=g7_31==1
    keep toilet_loan_any no_toilet respid constraint_* hh_total_value_all_assets access_toilet_supplies1 access_toilet_supplies2 access_toilet_supplies3 access_toilet_supplies4 advice_attend_fds advice_past3m advice_recent advice_source agri_asset_Carabao agri_asset_Cat agri_asset_Chicken agri_asset_Cow agri_asset_Dog agri_asset_Duck agri_asset_Goat agri_asset_Handtractor agri_asset_Horse agri_asset_Irrigationequipment agri_asset_Otherassets agri_asset_Pig agri_asset_Piglet agri_asset_Powersaw agri_asset_Rooster agri_asset_Thresher agri_asset_Turkey agri_asset_Waterpump agri_asset_agri_land agri_asset_land_area agri_asset_land_value hh_asset_Animalcart hh_asset_Bicycle hh_asset_Car hh_asset_Cellularphone hh_asset_Karaoke hh_asset_Landlinephone hh_asset_Motorcycle hh_asset_Personalcomputer hh_asset_Radio hh_asset_Refrigerator hh_asset_Television hh_asset_Tractor hh_asset_Washingmachine hh_asset_banca hh_asset_media_player hh_asset_motorbanca hh_asset_other hh_income_source_4p hh_income_source_Donation_ngo hh_income_source_Interest hh_income_source_Other hh_income_source_Pension hh_income_source_Remittances hh_income_source_Rental_income hh_income_source_Salary hh_income_source_Scholarship hhchar_material_floor hhchar_material_roof hhchar_material_wall hhchar_num_bedrooms hhchar_own_house hhchar_rent_house hhid jmpsan jmpwater jmpwater_drinking reported_programs_safe_water reported_programs_sanitation satisfaction_toilet survid toilet_feat_Door toilet_feat_Floortilesconcrete toilet_feat_Footrests toilet_feat_Fullycoveredroof toilet_feat_Fullyenclosedwall toilet_feat_Partcoveredroof toilet_feat_Partenclosedwall toilet_feat_Raisedplatform toilet_feat_Seat toilet_feat_Waterseal toilet_has_flies toilet_has_hw_soap_water toilet_has_hw_station toilet_has_leak toilet_improved toilet_loan_amount_improve toilet_loan_improvement toilet_location toilet_reason toilet_savings_improvement toilet_shared toilet_subsidy_amount_improve toilet_subsidy_any toilet_subsidy_total toilet_type toilet_under_construction  

  ****************************************
  *have to fix the hhids to match baseline
  ****************************************
    preserve
      import excel "$endline_doc/Endline Survey Casewise Data file", firstrow clear
      rename BaselineNo hhid
      destring hhid,replace
      replace TreatmentArm=subinstr(TreatmentArm, "{", "",.) 
      replace TreatmentArm=subinstr(TreatmentArm, "}", "",.) 
      replace TreatmentArm=subinstr(TreatmentArm, "_", "",.) 
      destring TreatmentArm,replace
      tempfile hhid_fix
      save `hhid_fix'
    restore
    *adding baseline ids to endline dataset
    merge 1:1 hhid using `hhid_fix',nogen

  *save data
    tolower *
    save z1,replace

********************
*loan roster dataset
********************
  *load data
    use "$baseline_dtInt/HH_Loans_2.12.16.dta",clear
    rename G9_9Have hh_has_loans
    recode hh_has_loans (2=0)

    rename G9_15 loan_amount
    recode loan_amount (988888=.) (999999=.)
    tolower*

  *collapse to household level
    collapse (max) hh_has_loans (sum) loan_amount,by(hhid)
    keep hhid hh_has_loans loan_amount
  *save data
    save z2,replace

********************
*hh roster dataset - household head characteristics
********************
  *load data
    use "$baseline_dtInt/HH_Roster_2.12.16.dta",clear
    tolower *

  *found some cases where children were selected as household head, so recoding children to be children 
    replace g2_2=3 if g2_2==1 & inrange(g_1_age,0,15) //i'll assume max age of household head is 15

  *not all households have a household head selected, if that's the case then making the spouse the household head
    gen is_head=g2_2==1
    egen count_heads=sum(is_head),by(hhid)

  *replacing spouse to be household head if no one else is selected in the household
    replace g2_2=1 if g2_2==2 & count_heads==0

  *still have 8 households where no household head is selected, i'll make oldest person to be household head in those cases
    egen max_age=max(g_1_age),by(hhid)

  *recounting household heads
    drop is_head count_heads
    gen is_head=g2_2==1
    egen count_heads=sum(is_head),by(hhid)

  *oldest person will be household head if no one else was selected yet
    replace g2_2=1 if max_age==g_1_age & count_heads==0

  *keeping hh head only
    keep if g2_2==1
  **household head characteristics
    rename g_1_age hh_head_age
    rename g2_1 hh_head_gender

  *rename K136 hh_head_marital_status
    rename g2_3 hh_head_educ

  *rename K138 hh_head_occupation
    *en hh_head_is_daylaborer = hh_head_occupation==9
    gen hh_head_has_basic_literacy = g2_4==1 | g2_5==1

    gen hh_head_worked_12m = inrange(g3_8,1,12) | inrange(g3_15,1,12) 
    gen hh_head_worked_1m=g3_4==1 | g3_11==1 | g3_18==1 | g3_23==1 
    recode g3_4 g3_11 g3_18 g3_23 (97777 =.) (98888=.) (99999=.)
    egen hh_head_income_1m=rsum(g3_4 g3_11 g3_18 g3_23)
    *rename L147 hh_head_job_type
    rename g3_16 hh_head_job_category 
    *rename L149 hh_head_payment_schedule

  **some household have more than 1 household head, keeping the oldest person who is tagged as HH head
    egen real_hh_head=max(hh_head_age),by(hhid) 
    egen count_hh_heads=count(hhid),by(hhid)
    keep if real_hh_head==hh_head_age

    drop count_hh_heads
    duplicates drop hhid,force
    keep hhid hh_head_age hh_head_educ hh_head_gender hh_head_has_basic_literacy hh_head_income_1m hh_head_job_category hh_head_worked_12m hh_head_worked_1m hhid
  *save file
    save z3,replace

********************
*hh roster dataset - household characteristics farm/ag
********************
  *load data
    use "$baseline_dtInt/HH_Roster_2.12.16.dta",clear
    tolower *
  *variable generation
    gen hh_is_agricultural= g3_17==1
    gen hh_is_fishing=g3_16==12
    collapse (max) hh_is_agricultural hh_is_fishing,by(hhid)
  *save data
    save z4,replace

********************
*hh roster dataset - membership count
********************
  *load data
    use "$baseline_dtInt/HH_Roster_2.12.16.dta",clear
    tolower *
  *dropping household heads
    drop if g2_2==1
    recode g3_4 g3_11 g3_18 g3_23 g3_24 (97777 =.) (98888=.) (99999=.)

  **household income
    gen hh_members_work=g3_1==1| g3_2==1| g3_9==1
    gen hh_members_work_count=g3_1==1| g3_2==1| g3_9==1

    rename g3_19 hh_agri_income
    recode hh_agri_income (977777=.)  (988888=.)  (999999=.) 
    egen hh_income_last4weeks=rsum(g3_4 g3_11 g3_18 g3_23)

    gen hh_fishing_income=hh_agri_income 
    replace hh_fishing_income=. if g3_16==12
    gen hh_members_work_family_bis=g3_22==1 | g3_25==1 | g3_26==1 | (g3_24>0 & g3_24!=.)
    rename g3_24 hh_family_bis_income 
    recode hh_family_bis_income (977777=.)  (988888=.)  (999999=.) 

  *collapse to hh level
    collapse (max)hh_members_work (sum) hh_members_work_count hh_agri_income hh_members_work_family_bis hh_income_last4weeks ///
              hh_fishing_income hh_family_bis_income ,by(hhid)
  *save data
    save z5,replace

********************
*household roster - count workers
********************
  *load data
    use "$baseline_dtInt/HH_Roster_2.12.16.dta",clear

    gen count_worker=G3_1==1
    gen count_adult=G_1_Age>18
    gen count_under5=G_1_Age<6
    gen children0_17=G_1_Age<18
    gen counthh_members=G_1_1Num

    collapse (first) counthh_members (sum) count_*,by(HHID)
    tolower*
  *save data
    save z6,replace

********************
*child roster - child illnesses
********************
  *load data
    use "$baseline_dtInt/HH_Child_Health_2.12.16.dta",clear

  **child reported illnesses
    gen illness_Fever=G11_S_1 ==1
    gen illness_Constantcough=G11_S_2 ==1
    gen illness_Congestion=G11_S_3 ==1
    gen illness_Panting=G11_S_4 ==1
    gen illness_Stomachpain=G11_S_5 ==1
    gen illness_Nausea=G11_S_6 ==1
    gen illness_Vomiting=G11_S_7 ==1
    gen illness_Diarrhea=G11_S_8 ==1
    gen illness_3plusbowelmovements=G11_S_9 ==1
    gen illness_Waterystool=G11_S_10 ==1
    gen illness_Mucusbloodstool=G11_S_11 ==1
    gen illness_Refusedeat=G11_S_12==1

  *collapsing to household level
    collapse (sum) illness_*,by(HHID)
    tolower*
  *save data
    save z7,replace

*********************
*household income
*********************
  *load data
    use "$baseline_dtInt/HH_Characteristics_2.12.16.dta",clear
  *recode some missing codes
    recode B3_16_* B3_17_* (999997 999998 999999 96 97 98 99=.)

  *generating the total amount of income
    egen annual_income=rsum(B3_16_* B3_17_*)

  *winsorizing baseline income, because few cases are too high
    winsor2 annual_income,cuts(0 99) replace

  *add household size variable
    preserve
      use "$baseline_dtInt/HH_Roster_2.12.16.dta",clear
      gen hhsize=1
      collapse(sum) hhsize,by(RESPID)
      tempfile hhsizefile
      save `hhsizefile'
    restore
    merge 1:1 RESPID using `hhsizefile',nogen keep(match)

  *calculate per capita income
    gen per_capita_income=annual_income/hhsize
    xtile quintile=per_capita_income, n(5)

    label var annual_income "Baseline annual income in PHP"
    label var per_capita_income "Baseline annual per capita income in PHP"
    label var quintile "Baseline quintile of income"

  *save as tempfile
    keep HHID annual_income per_capita_income quintile
    rename HHID hhid
  *save dataset
    save z8,replace

****************************************
**merging all files into a single dataset
****************************************
  *merge all datasets
    use z1,clear
    forvalues x = 2(1)8{
       di "merging file: z`x'"
      merge 1:1 hhid using z`x',nogen
    }
  *drop unnecessary variables
    cap drop nscbbgycode province citymunicipality barangay treatment

  ****************************
  *save final baseline dataset
  ****************************
    save "$baseline_dtFin/baseline_hh",replace
