
* ******************************************************************** *
* ******************************************************************** *
*                                                                      *
*                   export dataset for microdata repository
*                                                                      *
* ******************************************************************** *
* ******************************************************************** *
** IDS VAR:
** NOTES:
** WRITEN BY:        Odbayar Batmunkh
** Last date modified:  april 27 2021

** Define parts:
gl part1 0 //label some remaining variables
gl part2 0 //export as file
gl part3 0 //anonymize baseline data
gl part4 1 //label endline data

********************************
*label some remaining variables
********************************
if $part1{
	*load file
	use "$household/panel_clean",clear
	
	*label variables
	lab var no_toilet "Household has no toilet"
	lab var agri_asset_otherassets "Household has other agricultural assets"
	lab var hh_asset_other "Household has other assets"
	lab var toilet_improved "Household repaired or improved existing latrine in last year"
	lab var toilet_loan_improvement "Household took out loan for latrine improvement"
	lab var toilet_reason "Reasons for improving latrine"

	lab define toilet_reason_lbl ///
		1 	"Improved hygiene/cleanliness" ///
		2 	"More privacy" ///
		3 	"Convenience/saves time" ///
		4 	"Improved status/prestige" ///
		5 	"Improved health" ///
		6 	"More comfortable" ///
		7 	"Improved safety" ///
		8 	"Social pressure" ///
		9 	"Enforcement of government" ///
		10 	"CLTS/FDS triggering" ///
		11 	"Subsidy on offer" ///
		12 	"Had enough money to buy" ///
		13 	"Construction of new house" ///
		14 	"Event/wedding/funeral/visitors from outside coming" ///
		15 	"Other, specify" 

	lab val toilet_reason toilet_reason_lbl

	lab var advice_past3m "Household received any sanitation advice in the last 3 months"

	lab var jmpwater_drinking "Household's drinking water source is improved type - JMP definition"

	lab var hh_has_loans "Household has any loans"
	lab var loan_amount "Total value of loans"
	lab var hh_is_agricultural "Household has agricultural land"
	lab var hh_is_fishing "Household is involved in fishing"
	lab var hh_members_work "Household has atleast one member working"
	lab var hh_members_work_count "Number of household members that work"
	lab var hh_agri_income "Household income from agriculture"

	drop hh_members_work_family_bis

	lab var hh_income_last4weeks "Household income from last 4 weeks"
	lab var hh_fishing_income "Household income from fishing"

	drop hh_family_bis_income

	lab var illness_fever "# children with fever"
	lab var illness_constantcough "# children with constant cough"
	lab var illness_congestion "# children with congestion"
	lab var illness_panting "# children with panting"
	lab var illness_stomachpain "# children with stomach pain"
	lab var illness_nausea "# children with nausea"
	lab var illness_vomiting "# children vomiting"

	lab var illness_3plusbowelmovements "# children with 3 or more bowel movements per day"
	lab var illness_waterystool "# children with water stool"
	lab var illness_mucusbloodstool "# children with mucus or blood in stool"
	lab var illness_refusedeat "# children refusing to eat"
	
	lab var illness_refusedeat "# children refusing to eat"

	lab var toilet_has_flies "Flies seed in toilet area"

	lab var pppp_attendee "Who attended FDS"

	lab define pppp_attendee_lbl ///
		1 "Household Head" ///
		2 "Wife/Spouse" ///
		3 "Both Head and Wife/Spouse" ///
		4 "Child" ///
		9 "None" ///
		11 "Siblings" ///
		12 "Grandchildren" ///
		13 "Grandfather" ///
		14 "Grandmother" ///
		15 "Mother" ///
		16 "Niece/Nephew" ///
		17 "Cousin" ///
		18 "Aunt" ///
		19 "Daughter-in-law" ///
		20 "Mother-in-law" ///
		21 "Sister-in-law" ///
		22 "Son in-law" 

	lab val pppp_attendee pppp_attendee_lbl


	lab var pppp_last_amount "Amount Received from Last Pantawid Grant"
	lab var pppp_method "Mode of Receiving Pantawid Grant "

	lab var toilet_const_year "Year of latrine construction"

	lab define toilet_const_year_lbl ///
		1 "2014 or earlier" ///
		2 "(2015)" ///
		3 "(2016)" ///
		4 "Last year/ 2017" ///
		5 "This year/ 2018" 
	lab val toilet_const_year toilet_const_year_lbl

	lab var toilet_amount_spent_alt "Amount Spent on Toilet Facility"
	lab define toilet_amount_spent_alt_lbl ///
		0 "Free" ///
		1 "Below Php 5,000" ///
		2 "Php 5000 to Php 10,000" ///
		3 "More than Php 10,000" 
	lab val toilet_amount_spent_alt toilet_amount_spent_alt_lbl

	lab var toilet_spend_source "Source of Money for Toilet Facility"
	
	lab var toilet_distance_hw_station "Distance of HH’s Main Source of Drinking Water to Toilet Facility"
	lab var d40 "Sanitation Advice Heard in past 3 months "

	lab var advice_familiar_fds 		"Household remembers FDS module" 
	lab var advice_recent_fds 			"When was last FDS meeting?" 

	lab define advice_recent_fds_lbl ///
		1 "More than 1 year ago" ///
		2 "More than 6 months, but less than 1 year ago" ///
		3 "More than 3 months, but less than 6 months ago" ///
		4 "Less than 3 months ago" ///
		9 "Cannot remember " 

	lab val advice_recent_fds advice_recent_fds_lbl

	lab var advice_facilitator_fds 		"Who was facilitator of FDS session" 

	lab define advice_facilitator_fds_lbl ///
		1 "Municipal Link" ///
		2 "Rural Sanitary Inspector" ///
		3 "Municipal Health Officer" ///
		4 "Parent Leader" ///
		5 "Barangay Official" 

	lab val advice_facilitator_fds advice_facilitator_fds_lbl

	lab var advice_familiar_clts 		"Household remembers CLTS module" 
	lab var advice_recent_clts 			"When was last CLTS meeting?" 
	lab var advice_facilitator_clts 	"Who was facilitator of CLTS session"	

	lab val advice_recent_clts advice_recent_fds_lbl
	lab val advice_facilitator_clts advice_facilitator_fds_lbl

	lab var advice_source "Main source of sanitation advice"

	lab define label_1 ///
		1 "Neighbors/family" ///
		2 "Barangay official" ///
		3 "Municipal Link" ///
		4 "Public Health Office (MHO, BHW)" ///
		5 "School/Teacher" ///
		6 "Religious leader" ///
		7 "Television" ///
		8 "Radio" ///
		9 "SMS" ///
		10 "NGO" ///
		11 "Parent Leader" ///
		13 "Own initiative" ///
		14 "CSO" ///
		15 "Red cross" ///
		16 "Oxfam" ///
		17 "DSWD"
	lab val advice_source label_1

	lab var advice_recent "When was last sanitation advice given?"
	lab var has_asa_loan "Household took out loan from ASA"
	lab var advice_familiar_s4p "Household heard about S4P project"

	lab var bank_has_bank_account "Household has bank account(Savings or checking account)"
	lab var bank_member_coop "Household is member of cooperative"
	lab var bank_member_mfi "Household is member of MicroFinance group"

	rename bank_member_coop member_coop
	rename bank_member_mfi  member_mfi

	lab var toilet_built "Household constructed new toilet"
	lab var toilet_spent_amount_improvement "Amount spent on latrine improvements"
	lab var toilet_spent_amount_construction "Amount spent on new latrine construction"

	lab var toilet_loan_construction "Household took out loan for new latrine construction"
	lab var toilet_loan_amount_constru "Loan amount for latrine construction"

	drop f76a f76b

	lab var toilet_subsidy_improve "Household received government subsidy for latrine repair"
	lab var toilet_subsidy_constru "Household received government subsidy for new latrine construction"

	drop toilet_subsidy_amount_constru

	lab var advice_familiar_asa "Household received Orientation of ASA Philippines’ Products and Services"

	rename grid_g93_1g93 asa_response_1 
	rename grid_g93_2g93 asa_response_2 
	rename grid_g93_3g93 asa_response_3 
	rename grid_g93_4g93 asa_response_4 
	rename grid_g93_5g93 asa_response_5 
	rename grid_g93_6g93 asa_response_6 
	rename grid_g93_7g93 asa_response_7 
	rename grid_g93_8g93 asa_response_8 
	rename grid_g93_9g93 asa_response_9

	lab define label_2 ///
		5 "Very acceptable" ///
		4 "Acceptable" ///
		3 "Can’t say" ///
		2 "Unacceptable" ///
		1 "Very unacceptable" 
	lab val asa_response_1 asa_response_2 asa_response_3 asa_response_4 asa_response_5 asa_response_6 asa_response_7 asa_response_8 asa_response_9 label_2

	lab var asa_response_8 "Accredited masons who have to construct the toilet"
	lab var asa_response_9 "Processing of application"

	recode missed_payment sacrifice1 (2=0)
	lab var missed_payment "Where all payments made on time?"
	lab var sacrifice1 "Household made reduced other spending to make loan repayments"
	lab var sacrifice2 "What reductions were made?"

	rename sacrifice2 sacrifice_detail
	split  sacrifice_detail ,parse(,)
	destring sacrifice_detail1 sacrifice_detail2,replace
	lab var sacrifice_detail1 "What reductions were made to repay ASA loans?"
	lab var sacrifice_detail2 "What reductions were made to repay ASA loans?"

	lab define label_3 ///
		1 "We missed one or several meals" ///
		2 "We reduced household spending" ///
		3 "We used our savings intended for another purpose" ///
		4 "Accept laundry" ///
		5 "Selling fish" ///
		6 "Raising hogs /pig" ///
		7 "My husband applied on construction" ///
		999 "Don’t have any sacrifices/None" 
	lab val sacrifice_detail1 sacrifice_detail2 label_3

	lab var reported_quality_life "Overall Quality of Life"
	lab define label_4 ///
		5 "Much better now " ///
		4 "Somewhat better now " ///
		3 "The same " ///
		2 "Somewhat worse now " ///
		1 "Much worse now " 
	lab val reported_quality_life label_4

	label define reported_coverage_lbl 5 "All of us" 4 "Most of us" 3 "Some of us" 2 "Few of us" 1 "None of us"
	lab val reported_coverage_hw reported_coverage_od reported_coverage_use_toilet reported_coverage_safe_water reported_coverage_lbl

	lab var reported_coverage_hw "Share of HH practicing hand washing with soap"
	lab var reported_coverage_use_toilet "Share of HH using improved latrine"
	lab var reported_coverage_safe_water "Share of HH drinking water water"

	lab var reported_change_hw 					"Change in:Share of HH practicing hand washing with soap"
	lab var reported_change_od 					"Change in:Share of HH practicing OD"
	lab var reported_change_use_toilet 			"Change in:Share of HH using improved latrine"
	lab var reported_change_safe_water_drink	"Change in:Share of HH drinking water water"

	recode reported_change_hw reported_change_use_toilet reported_change_safe_water_drink (3=1) (2=-1) (1=0)
	label define change_lbl 1 "more od" 0 "no change"  -1 "less od"
	lab val reported_change_hw reported_change_use_toilet reported_change_safe_water_drink change_lbl

	lab var perception_impor_visit			"Someone talked to me or any member of my household about the importance of sanitation" 
	lab var perception_impor_comm_meeting	"I or a member of my household participated in community meetings on how to stop open defecation" 
	lab var perception_impor_aware			"I am aware of the negative effects of unsanitary practices" 
	lab var perception_impor_benefits		"I am aware of the benefits of having our own sanitary toilet"

	lab var perception_importance_toilet   "Self reported Importance of Having Own Toilet"
	lab define label_5 ///
		5 "Very important " ///
		4 "Somewhat important" ///
		3 "Can't say if important or not " ///
		2 "Somewhat not important" ///
		1 "Not important at all " 
	lab val perception_importance_toilet label_5

	lab var perception_best_way_toilet "What is best way to get your own toilet?"
	lab define label_6 ///
		1 "Save for it " ///
		2 "Borrow from relatives/ friends " ///
		3 "Borrow from financial/ lending institutions" ///
		4 "Look for grants/ programs from government " ///
		5 "Look for grants/ programs from NGOs " 
	lab val perception_best_way_toilet label_6

	lab var recommend "Does household recommend improving latrine to other households?"
	lab define label_7 ///
		5 "Very likely" ///
		4 "Somewhat likely" ///
		3 "Neither likely or unlikely" ///
		2 "Somewhat unlikely" ///
		1 "Very unlikely" 
	lab val perception_best_way_toilet label_7

	lab var hh_asset_airconditioner 	"Household owns assets: Air conditioner (quantity)" 
	lab var hh_asset_media_player2 		"Household owns assets: media player (quantity)" 
	lab var hh_asset_sala 				"Household owns assets: sala/couch (quantity)" 
	lab var hh_asset_dining 			"Household owns assets: dining set (quantity)" 
	lab var hh_asset_microwave 			"Household owns assets: microwave (quantity)" 
	lab var hh_asset_electricfan 		"Household owns assets: electric fan (quantity)"

	lab var access_mobile_phone " Time Length to Get to the Nearest Telephone/Mobile Phone"
	lab define label_8 ///
		1 "Telephone/mobile phone is in the house" ///
		2 "Less than 15 minutes" ///
		3 "15-30 minutes" ///
		4 "31-60 minutes" ///
		5 "More than an hour" ///
		6 "There is no telephone/mobile phone or do not use the telephone/mobile phone" 

	lab val access_mobile_phone label_8

	lab var access_poblacion "Household lives in poblacion (urban area/ downtown)"
	lab var access_freq_travel "How often household travels to poblacion (urban area/ downtown)"
	lab var access_cost_travel "Cost of travel to poblacion (urban area/ downtown)"

	lab var children0_17 "# of children aged 0-17 years old"
	lab var owns_land "Household owns land"
	lab var access_has_phone "Household owns a phone"
	lab var access_no_phone_access "Household lacks access to a phone"

	lab var loan_for_toilet "Household has loan for toilet improvement"

	lab var reported_constraint1 "Reported constraints to latrine improvement"  
	lab var reported_constraint2 "Reported constraints to latrine improvement"  
	lab var reported_constraint3 "Reported constraints to latrine improvement" 


	drop sacrifice21 sacrifice22

	lab var r_illness_fever				"ratio of children in household with symptoms: fever"
	lab var r_illness_constantcough		"ratio of children in household with symptoms: constant cough"
	lab var r_illness_congestion		"ratio of children in household with symptoms: congestion"
	lab var r_illness_panting			"ratio of children in household with symptoms: panting"
	lab var r_illness_stomachpain		"ratio of children in household with symptoms: stomach pain"
	lab var r_illness_nausea			"ratio of children in household with symptoms: nausea"
	lab var r_illness_vomiting			"ratio of children in household with symptoms: vomiting"
	lab var r_illness_diarrhea			"ratio of children in household with symptoms: diarrhea"
	lab var r_illness_3plusbowel		"ratio of children in household with symptoms: 3 plus bowel movements"
	lab var r_illness_waterystool		"ratio of children in household with symptoms: watery stool"
	lab var r_illness_mucusblood		"ratio of children in household with symptoms: mucus or blood in stool"
	lab var r_illness_refusedeat		"ratio of children in household with symptoms: refused to eat food"

	*drop unused variables
	drop round_r_illness_fever r_illness_fever_alt_c r_illness_fever_alt_a round_r_illness_constantcough r_illness_constantcough_alt_c r_illness_constantcough_alt_a round_r_illness_congestion r_illness_congestion_alt_c r_illness_congestion_alt_a round_r_illness_panting r_illness_panting_alt_c r_illness_panting_alt_a round_r_illness_stomachpain r_illness_stomachpain_alt_c r_illness_stomachpain_alt_a round_r_illness_nausea r_illness_nausea_alt_c r_illness_nausea_alt_a round_r_illness_vomiting r_illness_vomiting_alt_c r_illness_vomiting_alt_a round_r_illness_diarrhea r_illness_diarrhea_alt_c r_illness_diarrhea_alt_a round_r_illness_3plusbowel r_illness_3plusbowel_alt_c r_illness_3plusbowel_alt_a round_r_illness_waterystool r_illness_waterystool_alt_c r_illness_waterystool_alt_a round_r_illness_mucusblood r_illness_mucusblood_alt_c r_illness_mucusblood_alt_a round_r_illness_refusedeat r_illness_refusedeat_alt_c r_illness_refusedeat_alt_a toilet_type_0 change_0 toilet_type_1 change_1 toilet_type_2 change_2 toilet_type_3 change_3 toilet_type_4 change_4 toilet_type_5 change_5 toilet_type_6 change_6 toilet_type_7 change_7 toilet_type_8 change_8 toilet_type_9 change_9 toilet_type_10 change_10 toilet_type_11 change_11 toilet_type_12 change_12 toilet_type_96 change_96

	lab var adoption "household adopted which type of latrine?"
	lab var hh_head_has_basic_literacy "household head has basic literacy"
	lab var hh_head_worked_12m "household head worked in the last 12 months"
	lab var hh_head_worked_1m "household head worked in the last 1 month"

	lab var hh_head_marital_status "marital status of household head"
	lab var hh_head_occupation "occupation of household head"
	lab var hh_head_job_type "job type of household head"
	lab var hh_head_payment_schedule "how was household head paid?"
	lab define label_9 ///
		1 "In kind, not cash" ///
		2 "Per piece" ///
		3 "Per hour" ///
		4 "Per day" ///
		5 "Monthly" ///
		6 "Pakyaw" ///
		8 "Commission basis" ///
		8 "Weekly" ///
		9 "Per kilo" ///
		10 "Per head" ///
		11 "Per harvest" ///
		12 "Per passenger/Per person" ///
		13 "Every 3 months" ///
		14 "Every 15 days" ///
		16 "Quarterly" ///
		17 "Every 5 months" ///
		18 "Every 2 months" ///
		19 "Owner" ///
		20 "Every sack" ///
		99 "None" 
	lab val hh_head_payment_schedule label_9

	lab var hh_head_is_daylaborer "household head is a day laborer"
	lab var has_child_under5 "household has a child under 5 years old"
	lab var bcc_hardware "household is in hardware treatment"
	lab var bcc_mfi "household is in small mfi treatment"
	lab var bcc_bigmfi "household is in large mfi treatment"

	lab var muni_1	"municipality dummy: 1"
	lab var muni_2	"municipality dummy: 2"
	lab var muni_3	"municipality dummy: 3"
	lab var muni_4	"municipality dummy: 4"
	lab var muni_5	"municipality dummy: 5"
	lab var muni_6	"municipality dummy: 6"
	lab var muni_7	"municipality dummy: 7"
	lab var muni_8	"municipality dummy: 8"
	lab var muni_9	"municipality dummy: 9"
	lab var muni_10	"municipality dummy: 10"
	lab var muni_11	"municipality dummy: 11"
	lab var muni_12	"municipality dummy: 12"
	lab var muni_13	"municipality dummy: 13"
	lab var muni_14	"municipality dummy: 14"
	lab var muni_15	"municipality dummy: 15"
	lab var muni_16	"municipality dummy: 16"
	lab var muni_17	"municipality dummy: 17"

	lab var count_sources "how many different sources of support for latrine improvement"
	lab var toilet_important "household head considers latrine to be important"
	lab var attend_fds  "household attended FDS session"
	lab var attend_clts  "household attended CLTS session"
	lab var attend_asa  "household attended ASA session"
	lab var attend_s4p  "household attended S4P session"
  
	lab var no_support "household received no support for latrine improvement"

	drop overlaps temp_overlaps overlap is_jmpsan brgy_jmpsan is_hh brgy_hh observed_od
	drop respid

	foreach x of varlist region province municipality barangay{
		encode `x',gen (enc_`x')
	}

	drop region province municipality barangay

	forvalues i = 1/7 {
	
		gen advice_topic_`i'=strpos(d40, "`i'") > 0
		replace advice_topic_`i'=. if d40 == ""
	}

	lab var advice_topic_1 "Advice:Drink safe water"
	lab var advice_topic_2 "Advice:Use a toilet facility"
	lab var advice_topic_3 "Advice:Improve/upgrade the toilet facility"
	lab var advice_topic_4 "Advice:Wash hands/face/body"
	lab var advice_topic_5 "Advice:Food hygiene"
	lab var advice_topic_6 "Advice:Keep the environment clean"
	lab var advice_topic_7 "Advice:Put chlorine in toilet bowl"

	forvalues i = 1/5 {
	
		gen toilet_spending_source_`i'=strpos(toilet_spend_source, "`i'") > 0
		replace toilet_spending_source_`i'=. if toilet_spend_source == ""
	}

	drop toilet_spend_source

	lab var toilet_spending_source_1 "Toilet spending source: Own money"
	lab var toilet_spending_source_2 "Toilet spending source: Loan from family/relatives"
	lab var toilet_spending_source_3 "Toilet spending source: Grant from Government (LGU/DSWD)"
	lab var toilet_spending_source_4 "Toilet spending source: Grant from NGO"
	lab var toilet_spending_source_5 "Toilet spending source: Loan from Microfinance Institutions"

	encode citymunicipality,gen(city)
	drop citymunicipality

	drop d40

	*display string variables
	ds *,has(type string)
	br `r(varlist)'

	drop sacrifice_detail

}

********************************
*export as file
********************************
if $part2{
	label data "WASH Philippines IE analysis dataset"
	save "$household/export_panel_clean",replace
}

********************************
*anonymize baseline data
********************************
if $part3{
	*****************
	*baseline hh data
	*****************
	*load household data
		use "$baseline_dtInt\HH_Characteristics_2.12.16.dta" ,clear

	*browse list of strings
		ds,has(type string)
		br `r(varlist)' 

	*ok to drop all
		drop `r(varlist)' 

	*drop phone numbers
		drop CONTACT2_1 CONTACT2_2 CONTACT2_95

	*drop gps
		drop GPS_LAT GPS_LNG

	*drop empty variables
		missings dropvars,force

	*Save for export
		save "$household\HH_Characteristics_2.12.16.dta" ,replace
	
	*****************
	*child health data
	*****************
	*load household data
		use "$baseline_dtInt\HH_Child_Health_2.12.16.dta" ,clear

	*browse list of strings
		ds,has(type string)
		br `r(varlist)' 

	*drop empty variables
		missings dropvars,force

	*Save for export
		save "$household\HH_Child_Health_2.12.16.dta" ,replace

	*****************
	*loans data
	*****************
	*load household data
		use "$baseline_dtInt\HH_Loans_2.12.16.dta" ,clear

	*browse list of strings
		ds,has(type string)
		br `r(varlist)' 

	*drop empty variables
		missings dropvars,force

	*Save for export
		save "$household\HH_Loans_2.12.16.dta" ,replace

	*****************
	*hh roster data
	*****************
	*load household data
		use "$baseline_dtInt\HH_Roster_2.12.16.dta" ,clear

	*browse list of strings
		ds,has(type string)
		br `r(varlist)' 

	*ok to drop all
		drop `r(varlist)' 

	*drop empty variables
		missings dropvars,force
	*Save for export
		save "$household\HH_Roster_2.12.16.dta" ,replace
	
}

********************************
*anonymize endline data and label variables
********************************
if $part4{
	*load unlabeled data
		use "$endline_dtInt\endline.dta",clear

	lab var A01	"A01  Number of People Living in HH "
	lab var A02	"A02  Pantawid Grantee in HH "
	lab var A03	"A03  Relationship to HH Head"
	
	lab var Grid_A04_1A04	"A04  Number of Children Aged 0-14 y.o"
	lab var Grid_A04_2A04	"A04  Number of Children Aged 15-17 y.o"

	lab var Grid_A05_1A05	"A05  Number of Children Currently Studying a - Pre-school or Elementary"
	lab var Grid_A05_2A05	"A05  Number of Children Currently Studying b - High School? (Grade 7 to 12)"
	lab var Grid_A05_3A05	"A05  Number of Children Currently Studying c - College"

	lab var A06	"A06  Number of Children Visiting Health Center"
	lab var A07	"A07  Attendee/s of Family Development Sessions (FDS)"
	lab var A08	"A08  Amount Received from Last Pantawid Grant"
	lab var A09	"A09  Expenditures Last Pantawid Grant Used On"
	lab var A10	"A10 Mode of Receiving Pantawid Grant "
	lab var A11	"A11 Amount Spent on Transportation When Claiming Pantawid Grant"
	lab var B12a	"B12a  Main source of water supply"
	lab var B12b	"B12b  Incidence of Water Source for Drinking Water"
	lab var B12c	"B12c  Source of Drinking Water "
	lab var B12d	"B12d  Other Sources of Drinking Water"
	split B12d,parse(,)

	lab var B12d1 "B12d  Other Sources of Drinking Water"
	lab var B12d2 "B12d  Other Sources of Drinking Water"
	lab var B12d3 "B12d  Other Sources of Drinking Water"
	
	lab var B13a	"B13a  Source of HH Main Water/ Drinking Water "
	lab var B13b	"B13b  Source of HH Main Water/ Drinking Water "
	lab var B14a	"B14a  Duration of Getting Water"
	lab var B14b	"B14b  Duration of Getting Water"
	lab var B15	"B15  Availability of Drinking Water"
	lab var B16	"B16  Monthly Payment of Drinking Water "
	lab var B17	"B17  Frequency of Payment"
	lab var B18	"B18  Incidence of Drinking Water in a Storage Container"
	lab var B19	"B19  Type of Storage Container"
	lab var B20	"B20  Incidence of Covered Water Storage Container"
	lab var B21	"B21  Ways of Obtaining Water from the Container"
	lab var B22	"B22  Incidence of Making Water Safer to Drink"
	lab var B23	"B23  Ways to Make Water Safer to Drink"

	split B23,parse(,)
	destring B231 B232 B233 B234 B235 B236 B237,replace
	lab var B231	"B23  Ways to Make Water Safer to Drink"
	lab var B232	"B23  Ways to Make Water Safer to Drink"
	lab var B233	"B23  Ways to Make Water Safer to Drink"
	lab var B234	"B23  Ways to Make Water Safer to Drink"
	lab var B235	"B23  Ways to Make Water Safer to Drink"
	lab var B236	"B23  Ways to Make Water Safer to Drink"
	lab var B237	"B23  Ways to Make Water Safer to Drink"

	lab var C24	"C24  Type of Toilet Facility"
	lab var C25	"C25  Sharing of Facilities to Other HH"
	lab var C26	"C26  Location of Toilet Facility"
	lab var C27	"C27  Construction of Toilet Facility"
	lab var C28	"C28  Amount Spent on Toilet Facility"
	lab var C29	"C29  Source of Money for Toilet Facility"
	split C29,parse(,)
	destring C291 C292 C293,replace
	lab var C291	"C29  Source of Money for Toilet Facility"
	lab var C292	"C29  Source of Money for Toilet Facility"
	lab var C293	"C29  Source of Money for Toilet Facility"


	lab var C30	"C30  Type of Floor of Toilet Facility"
	lab var C31	"C31  Incidence of Any Leaks or Overflowing Sludge"

	lab var Grid_C32_1C32	"C32  Features of Toilet Facility: Raised platform"
	lab var Grid_C32_2C32	"C32  Features of Toilet Facility: Foot rests"
	lab var Grid_C32_3C32	"C32  Features of Toilet Facility: Seat"
	lab var Grid_C32_4C32	"C32  Features of Toilet Facility: Floor tiles/concrete"
	lab var Grid_C32_5C32	"C32  Features of Toilet Facility: Fully enclosed wall"
	lab var Grid_C32_6C32	"C32  Features of Toilet Facility: Partially enclosed wall"
	lab var Grid_C32_7C32	"C32  Features of Toilet Facility: Fully covered roof"
	lab var Grid_C32_8C32	"C32  Features of Toilet Facility: Partially covered roof"
	lab var Grid_C32_9C32	"C32  Features of Toilet Facility: Door/curtain"
	lab var Grid_C32_10C32	"C32  Features of Toilet Facility: Water seal"

 	lab var C33	"C33  Type of Roof of Toilet Facility"
	lab var C34	"C34  Type of Walls of Toilet Facility"
	lab var C35	"C35  Presence of Flies"
	lab var C36	"C36  Presence of Wash Basin in Toilet Facility"
	lab var C37	"C37  Presence of Soap and Water"
	lab var C38	"C38  Distance of HH’s Main Source of Drinking Water to Toilet Facility"
	lab var C39	"C39  Overall Satisfaction of Toilet Facility"
	lab var D40	"D40  Sanitation Advice Heard in P3M "
	split D40,parse(,)
	destring D401 D402 D403 D404 D405 D406 D407,replace
	lab var D401	"D40  Sanitation Advice Heard in P3M "
	lab var D402	"D40  Sanitation Advice Heard in P3M "
	lab var D403	"D40  Sanitation Advice Heard in P3M "
	lab var D404	"D40  Sanitation Advice Heard in P3M "
	lab var D405	"D40  Sanitation Advice Heard in P3M "
	lab var D406	"D40  Sanitation Advice Heard in P3M "
	lab var D407	"D40  Sanitation Advice Heard in P3M "

	lab var D41	"D41  Main Source of Sanitation Advice"
	lab var D42	"D42  Recentness of Learning About Improving Toilet Facility"
	lab var D43	"D43  Incidence of Attending Family Development Session"
	lab var D44a	"D44a  Familiarity on FDS Module"
	lab var D44b	"D44b  Familiarity on CLTS"
	lab var D45a	"D45a  Last Discussion of FDS Module"
	lab var D45b	"D45b  Last Discussion of CLTS"
	lab var D46a	"D46a  FDS Session Facilitator"
	lab var D46b	"D46b  CLTS Facilitator"

	lab var Grid_D47_1D47 	"D47  Overall Satisfaction on Sanitation Programs: FDS"
	lab var Grid_D47_2D47 	"D47  Overall Satisfaction on Sanitation Programs: CLTS"

	lab var Grid_D48_1D48	"D48  Grant or Subsidy for Toilet Construction or Repair: From the Mayor’s or Barangay Captain’s office"
	lab var Grid_D48_2D48	"D48  Grant or Subsidy for Toilet Construction or Repair: From the SLP"
	lab var Grid_D48_3D48	"D48  Grant or Subsidy for Toilet Construction or Repair: From the Kalahi Program"
	lab var Grid_D48_4D48	"D48  Grant or Subsidy for Toilet Construction or Repair: From S4P (25% subsidy) / ASA"
	lab var Grid_D48_5D48	"D48  Grant or Subsidy for Toilet Construction or Repair: From S4P (50% subsidy) / ASA"


	lab var D48_1 "D48.1  Incidence of Signing a Contract with ASA Philippines"
	lab var D49	"D49  Familiarity on S4P"
	lab var Grid_D50_1D50	"D50  Overall Satisfaction on S4P"

	lab var Grid_E52_1E52	"E52  Exposure to Banking System: Bank account (Savings or checking account)"
	lab var Grid_E52_2E52	"E52  Exposure to Banking System: Membership in cooperatives"
	lab var Grid_E52_3E52	"E52  Exposure to Banking System: Membership in MFIs/ lending institutions (e.g. ASA Philippines, etc.)"




	lab var E53	"E53  Period of Owning Bank Account"
	lab var E54	"E54  Amount of Money in all HH Bank Accounts"
	lab var E55	"E55  Possession of Debit/ ATM Card"
	lab var E56	"E56  Borrowing"
	lab var E57	"E57  Number of Loans for Payment"
	lab var E58	"E58  Number of Loans Used for Toilet Facility"
	lab var E59	"E59  Primary Borrower in HH"
	lab var E60	"E60  Period of Getting the Loan"
	lab var E61	"E61  Source of Loan"
	lab var E62	"E62  Purpose of Obtaining Loan"
	split E62,parse(,)
	destring E621 E622 E623 E624 E625 E626,replace
	lab var E621	"E62  Purpose of Obtaining Loan"
	lab var E622	"E62  Purpose of Obtaining Loan"
	lab var E623	"E62  Purpose of Obtaining Loan"
	lab var E624	"E62  Purpose of Obtaining Loan"
	lab var E625	"E62  Purpose of Obtaining Loan"
	lab var E626	"E62  Purpose of Obtaining Loan"

	lab var E63	"E63  Amount Borrowed"
	lab var E64	"E64  Interest Rate of Loan"
	lab var E65	"E65  Amount of Total Interest"
	lab var E66	"E66  Incidence of Having Started Paying Off the Loan"
	lab var E67	"E67  Frequency of Paying Loan"
	lab var E68	"E68  Collateral Used for Loan"
	lab var E69	"E69  Days Obtaining the Loan"
	lab var E70	"E70  Amount Already Repaid"
	lab var E70_C_1	"E70  Amount Already Repaid:PHP"

	lab var Grid_F71_1F71	"F71  Incidence of Repairing or Improving Toilet in P12M:Repair or improve your existing toilet"
	lab var Grid_F71_2F71	"F71  Incidence of Repairing or Improving Toilet in P12M:Construct a new toilet"

	lab var F72a	"F72a  Toilet Repairer "
	lab var F72b	"F72b  Toilet Constructor "
	lab var F73a	"F73a  Amount Spent on Last Repair"
	lab var F73a_C_97	"F73a  Amount Spent on Last Repair: PHP"
	lab var F73b	"F73b  Amount Spent on Construction"
	lab var F73b_C_1	"F73b  Amount Spent on Construction:PHP"
	lab var F74a	"F74a  Loan for repair or improvement "
	lab var F74b	"F74b  Loan for construction "
	lab var F75a	"F75a  Source of Loan for Repair"
	lab var F75b	"F75b  Source of Loan for Construction"
	lab var F76a	"F76a  Amount of Loan for Repair"
	lab var F76a_C_1	"F76a  Amount of Loan for Repair:PHP"
	lab var F76b	"F76b  Amount of Loan for Construction"
	lab var F76b_C_1	"F76b  Amount of Loan for Construction:PHP"
	lab var F77a	"F77a  Incidence of Receiving Government Subsidy for Repair"
	lab var F77b	"F77b  Incidence of Receiving Government Subsidy for Construction"
	lab var F78a	"F78a  Amount of Subsidy Received for Repair"
	lab var F78a_C_1	"F78a  Amount of Subsidy Received for Repair:PHP"
	lab var F78b	"F78b  Amount of Subsidy Received for Construction"
	lab var F78b_C_1	"F78b  Amount of Subsidy Received for Construction:PHP"
	lab var F79	"F79  Source of Knowledge on Toilet Facilities, Supplies and Cost"
	
	lab var F80	"F80  Main Reasons of Improving Toilet Facility "
	split F80,parse(,)
	destring F801 F802 F803,replace
	lab var F801	"F80  Main Reasons of Improving Toilet Facility "
	lab var F802	"F80  Main Reasons of Improving Toilet Facility "
	lab var F803	"F80  Main Reasons of Improving Toilet Facility "

	lab var F81	"F81  Decision Maker to Improve Toilet Facility"
	lab var F82	"F82  Main Constraint in Improving or Constructing Toilet Facility"
	split F82,parse(,)
	destring F821 F822 F823,replace
	lab var F821	"F80  Main Reasons of Improving Toilet Facility "
	lab var F822	"F80  Main Reasons of Improving Toilet Facility "
	lab var F823	"F80  Main Reasons of Improving Toilet Facility "

	lab var G100	"G100  Unacceptable Terms and Conditions "
	split G100,parse(,)
	destring G1001 G1002 G1003 G1004,replace
	lab var G1001	"G100  Unacceptable Terms and Conditions "
	lab var G1002	"G100  Unacceptable Terms and Conditions "
	lab var G1003	"G100  Unacceptable Terms and Conditions "
	lab var G1004	"G100  Unacceptable Terms and Conditions "


	lab var G101	"G101  Type of Toilet Repair, Upgrade or Improvement "
	lab var G102	"G102  Benefits of Improving/ Upgrading Toilet Facility"
	split G102,parse(,)
	destring G1021 G1022 G1023,replace
	lab var G1021	"G102  Benefits of Improving/ Upgrading Toilet Facility"
	lab var G1022	"G102  Benefits of Improving/ Upgrading Toilet Facility"
	lab var G1023	"G102  Benefits of Improving/ Upgrading Toilet Facility"


	lab var G103	"G103  Importance of ASA Philippines’ Role in Toilet Improvement"
	lab var G83	"G83  Orientation of ASA Philippines’ Products and Services"
	lab var G84	"G84  ASA Philippines Orientation Conductor"
	lab var G85	"G85  Level of Comprehension of Financial Packages"
	lab var G86	"G86  Difficulty in Comprehension of Financial Packages"
	lab var G87	"G87  Interest in ASA Philippines Offer"
	lab var G88	"G88  Incidence of Signing Up with ASA Philippines"
	lab var G89	"G89  Decision Maker in Signing Up with ASA Philippines"
	lab var G90	"G90  Purpose of Loan from ASA Philippines"
	lab var G91	"G91  Reasons for Borrowing Money to Have Own Toilet "
	split G91,parse(,)
	destring G911 G912 G913 G914,replace
	lab var G911	"G91  Reasons for Borrowing Money to Have Own Toilet "
	lab var G912	"G91  Reasons for Borrowing Money to Have Own Toilet "
	lab var G913	"G91  Reasons for Borrowing Money to Have Own Toilet "
	lab var G914	"G91  Reasons for Borrowing Money to Have Own Toilet "

	lab var G92	"G92  Benefits of Having Own Toilet Facility"
	split G92,parse(,)
	destring G921 G922 G923,replace
	lab var G921	"G92  Benefits of Having Own Toilet Facility"
	lab var G922	"G92  Benefits of Having Own Toilet Facility"
	lab var G923	"G92  Benefits of Having Own Toilet Facility"
 
	lab var Grid_G93_1G93	"G93  Acceptability of Terms and Conditions of ASA Philippines: a. Amount of loan / Halaga ng loan o utang "
	lab var Grid_G93_2G93	"G93  Acceptability of Terms and Conditions of ASA Philippines: b. Amount of discount (subsidy) / Halaga ng diskwento (tulong mula sa pamahalaan)"
	lab var Grid_G93_3G93	"G93  Acceptability of Terms and Conditions of ASA Philippines: c. Amount of weekly payment / Halaga ng lingguhang bayad"
	lab var Grid_G93_4G93	"G93  Acceptability of Terms and Conditions of ASA Philippines: d. Weekly mode of payment / Lingguhang pagbabayad"
	lab var Grid_G93_5G93	"G93  Acceptability of Terms and Conditions of ASA Philippines: e. Payment during weekly meetings / Lingguhang pagbabayad kada may meeting  "
	lab var Grid_G93_6G93	"G93  Acceptability of Terms and Conditions of ASA Philippines: f. Loan term of 6 or 12 months / Loan term ng anim o labindalawang buwan"
	lab var Grid_G93_7G93	"G93  Acceptability of Terms and Conditions of ASA Philippines: g. Disbursement at the ASA branch office / Pagbabayad sa brand office ng ASA"
	lab var Grid_G93_8G93	"G93  Acceptability of Terms and Conditions of ASA Philippines: h. Accredited masons who have to construct the toilet / Accredited o kilalang mga mason na gagawa ng palikuran"
	lab var Grid_G93_9G93	"G93  Acceptability of Terms and Conditions of ASA Philippines: g. Processing of application / Pagproseso ng application"


	lab var G94	"G94  Incidence of On-time Payments"
	lab var G95	"G95  Source of Fund for Payments"
	split G95,parse(,)
	destring G951 G952 G953,replace
	lab var G951	"G95  Source of Fund for Payments"
	lab var G952	"G95  Source of Fund for Payments"
	lab var G953	"G95  Source of Fund for Payments"


	lab var G96	"G96  Primary Reason for Missed Payments "
	lab var G97	"G97  Incidence of Making Sacrifices for Payment Obligation"
	lab var G98	"G98  Sacrifices Made for Weekly Obligation"
	split G98,parse(,)
	destring G981 G982,replace
	lab var G981	"G98  Sacrifices Made for Weekly Obligation"
	lab var G982	"G98  Sacrifices Made for Weekly Obligation"


	lab var G99	"G99  Reasons for Not Signing Up with ASA Philippines"
	split G99,parse(,)
	destring G991 G992 G993 G994,replace
	lab var G991	"G99  Reasons for Not Signing Up with ASA Philippines"
	lab var G992	"G99  Reasons for Not Signing Up with ASA Philippines"
	lab var G993	"G99  Reasons for Not Signing Up with ASA Philippines"
	lab var G994	"G99  Reasons for Not Signing Up with ASA Philippines"


	lab var H104	"H104  Overall Satisfaction on Quality of Toilet Facility"

	lab var Grid_H105_1H105	"H105 Assessment of Quality of Toilet Constructed: Functional? "
	lab var Grid_H105_2H105	"H105 Assessment of Quality of Toilet Constructed: Durable? "
	lab var Grid_H105_3H105	"H105 Assessment of Quality of Toilet Constructed: Easy to maintain? "

	lab var H106	"H106  Quality Expectation on Toilet Facility"
	lab var H107	"H107  Incidence of Having Any Issues and Concerns"
	lab var H108	"H108  Issues and Concerns on Newly Constructed Toilet"
	split H108,parse(,)
	destring H1081 H1082 H1083,replace
	lab var H1081	"H108  Issues and Concerns on Newly Constructed Toilet"
	lab var H1082	"H108  Issues and Concerns on Newly Constructed Toilet"
	lab var H1083	"H108  Issues and Concerns on Newly Constructed Toilet"


	lab var Grid_H109_1H109	"H109  Incidence of Addressing Issues and Concerns:a. ASA Philippines"
	lab var Grid_H109_2H109	"H109  Incidence of Addressing Issues and Concerns:b. Masons"

 

	lab var H110	"H110   Complaints Channel of ASA Philippines"
	lab var H111	"H111   Who to Discuss Issues and Concerns With"
	lab var H112	"H112   Incidence if Concern Has Been Acted Upon"
	lab var H113	"H113  Opinion on Grievance Mechanism of ASA Philippines"
	lab var H114	"H114  Opinion on ASA Philippine Staff’s Conduct and Behavior"
	lab var H115	"H115  Mason Influence on Constructing New Toilet"
	lab var H116	"H116  Importance of Toilet Quality to Encourage Availment of ASA Loan"
	lab var H117	"H117  Overall Quality of Life"
	lab var H118	"H118  Contribution of Having Improved Toilet to Better QoL"
	lab var H119	"H119  Neighbors Interested in Having Own Toilet"
	lab var H120	"H120  Toilet Plans in the Next 2 years"
	lab var H121	"H121  PRIORITIZATION ON PREVENTION VS. CURE"

	lab var Grid_I122_1I122	"I122   Issues in the Barangay:Unhygienic practices (e.g., open defecation, not proper handwashing, etc.)"
	lab var Grid_I122_2I122	"I122   Issues in the Barangay:Issues on littering"
	lab var Grid_I122_3I122	"I122   Issues in the Barangay:Sanitation-related diseases"
	lab var Grid_I122_4I122	"I122   Issues in the Barangay:Availability of safe water"

	lab var Grid_I123_1I123	"I123 Sanitation Programs and Initiatives in the Barangay:Safe water"
	lab var Grid_I123_2I123	"I123 Sanitation Programs and Initiatives in the Barangay:Sanitation and hygiene"

	lab var Grid_I124_1I124	"I124 Sanitation Practices:I124.a  Proper handwashing (at least before meals and with soap)"
	lab var Grid_I124_2I124	"I124 Sanitation Practices:I124.b  Open defecation (defecating in the open)"
	lab var Grid_I124_3I124	"I124 Sanitation Practices:I124.c  Defecate in a proper toilet (i.e., covered or with flush)"
	lab var Grid_I124_4I124	"I124 Sanitation Practices:I124.d  Ensure we have safe drinking water in the household"

	lab var Grid_I125_1I125	"I125  Change in Sanitation Practices in Past Year:a. Proper handwashing (at least before meals and with soap)"
	lab var Grid_I125_2I125	"I125  Change in Sanitation Practices in Past Year:b. Open defecation (defecating in the open)"
	lab var Grid_I125_3I125	"I125  Change in Sanitation Practices in Past Year:c. Defecate in a proper toilet (i.e., covered or with flush)"
	lab var Grid_I125_4I125	"I125  Change in Sanitation Practices in Past Year:d. Ensure we have safe drinking water in the household"

	lab var Grid_I126_1I126	"I126  Importance of Sanitation:Someone talked to me or any member of my household about the importance of sanitation"
	lab var Grid_I126_2I126	"I126  Importance of Sanitation:I or a member of my household participated in community meetings on how to stop open defecation"
	lab var Grid_I126_3I126	"I126  Importance of Sanitation:I am aware of the negative effects of unsanitary practices"
	lab var Grid_I126_4I126	"I126  Importance of Sanitation:I am aware of the benefits of having our own sanitary toilet"

	lab var I127	"I127  Importance of Having Own Toilet"
	
	lab var Grid_I128_1I128	"I128  Ways to Have Own Toilet: unknown code"  
	lab var Grid_I128_2I128	"I128  Ways to Have Own Toilet: unknown code"  
	lab var Grid_I128_3I128	"I128  Ways to Have Own Toilet: unknown code"  
	lab var Grid_I128_4I128	"I128  Ways to Have Own Toilet: unknown code"  
	lab var Grid_I128_5I128	"I128  Ways to Have Own Toilet: unknown code" 

	lab var I129	"I129  Best Way to Have Own Toilet "
	lab var I130	"I130  Recommendation of building toilet to other HHs"
	lab var J131	"J131  Incidence of Having HH Members Under 5 Years Old"

	lab var Grid_J132_1J132	"J132  Incidence of Experiencing Illnesses in P4W:Fever  "
	lab var Grid_J132_2J132	"J132  Incidence of Experiencing Illnesses in P4W:Constant cough  "
	lab var Grid_J132_3J132	"J132  Incidence of Experiencing Illnesses in P4W:Congestion  "
	lab var Grid_J132_4J132	"J132  Incidence of Experiencing Illnesses in P4W:Panting/wheezing/difficulty in breathing  "
	lab var Grid_J132_5J132	"J132  Incidence of Experiencing Illnesses in P4W:Stomach pain or cramps  "
	lab var Grid_J132_6J132	"J132  Incidence of Experiencing Illnesses in P4W:Nausea  "
	lab var Grid_J132_7J132	"J132  Incidence of Experiencing Illnesses in P4W:Vomiting  "
	lab var Grid_J132_8J132	"J132  Incidence of Experiencing Illnesses in P4W:Diarrhea  "
	lab var Grid_J132_9J132	"J132  Incidence of Experiencing Illnesses in P4W:3 or more bowel movements in one day and one night  "
	lab var Grid_J132_10J132	"J132  Incidence of Experiencing Illnesses in P4W:Watery or soft stool  "
	lab var Grid_J132_11J132	"J132  Incidence of Experiencing Illnesses in P4W:Mucus or blood in stool  "
	lab var Grid_J132_12J132	"J132  Incidence of Experiencing Illnesses in P4W:Refused to feed/eat"

	lab var K133	"K133  Name of HH Head"
	lab var K134	"K134  Date of Birth of HHH"
	lab var K135	"K135  Sex of HHH"
	lab var K136	"K136  Marital Status of HHH"
	lab var K137	"K137  Level of Education of HHH"
	lab var K138	"K138  Primary Occupation of HHH"
	lab var K139	"K139  Primary Language in the HH"
	lab var K140	"K140  Basic Literacy of HHH"
	lab var L141	"L141  Incidence of Hhead Earning Income in P12M"
	lab var L142	"L142  Labor for Other People in P4W"
	lab var L143	"L143  Amount Earned While Working in P4W"
	lab var L143_C_1	"L143  Amount Earned While Working in P4W: PHP"
	lab var L144	"L144  Number of Working Hours Per Day in P4W"
	lab var L144_C_1	"L144  Number of Working Hours Per Day in P4W:PHP"
	lab var L145	"L145  Number of Working Days in P7D"
	lab var L145_C_1	"L145  Number of Working Days in P7D: DAYS"
	lab var L146	"L146  Number of Working Months in P12M"
	lab var L146_C_1	"L146  Number of Working Months in P12M: MONTHS"
	lab var L147	"L147  Nature of Employment"
	lab var L148	"L148  Class of Worker"
	lab var L149	"L149  Basis of Payment"
	lab var L150	"L150  HH Members with Work/ Business"
	lab var L151	"L151  Number of HH members with Work/ Business"
	lab var L151_C_1	"L151  Number of HH members with Work/ Business: Number"
	lab var L152	"L152  Incidence of Growing Crops"
	lab var L153	"L153  Net Profit of Growing Crops in P12M"
	lab var L154	"L154  Incidence of HH member Who Has Done Fishing"
	lab var L155	"L155  Net Profit of Fishing Activity in P12M"
	lab var L156	"L156  Incidence of HH member Who Worked in Family-owned, Non-farm business in P12M"
	lab var L157	"L157  Net Profit of Other Business in P12M"

	lab var Grid_L157_1_1L157_1 "L157.1  Other Sources of Income in P12M: L157.1.a -  Interest or investment income"
	lab var Grid_L157_1_2L157_1 "L157.1  Other Sources of Income in P12M: L157.1.b -  Remittances (funds or goods) from people working outside your hometown"
	lab var Grid_L157_1_3L157_1 "L157.1  Other Sources of Income in P12M: L157.1.c -  Renting building, land, vehicle, equipment or machinery, animals (horse, livestock, etc.) to other"
	lab var Grid_L157_1_4L157_1 "L157.1  Other Sources of Income in P12M: L157.1.d -  Scholarship"
	lab var Grid_L157_1_5L157_1 "L157.1  Other Sources of Income in P12M: L157.1.e - Government transfer/ Pantawid grant"
	lab var Grid_L157_1_6L157_1 "L157.1  Other Sources of Income in P12M: L157.1.f -  Donation, grant from community groups, LGU, NGO, religious organizations, etc. "
	lab var Grid_L157_1_7L157_1 "L157.1  Other Sources of Income in P12M: L157.1.g -  Pension and retirement, and Social Security benefits"
	lab var Grid_L157_1_8L157_1 "L157.1  Other Sources of Income in P12M: L157.1.h - Other sources (specify)"
	lab var Grid_L157_1_9L157_1 "L157.1  Other Sources of Income in P12M: L157.1.i - Income/ Salary"

	lab var Grid_M158_1M158	"M158  Presence of Household Conveniences:M158.a.  Radio"
	lab var Grid_M158_2M158	"M158  Presence of Household Conveniences:M158.b.  Television"
	lab var Grid_M158_3M158	"M158  Presence of Household Conveniences:M158.c.  VTR/VHS/VCD/DVD Player"
	lab var Grid_M158_4M158	"M158  Presence of Household Conveniences:M158.d.  Landline/Wireless phone"
	lab var Grid_M158_5M158	"M158  Presence of Household Conveniences:M158.e.  Cellular phone"
	lab var Grid_M158_6M158	"M158  Presence of Household Conveniences:M158.f.  Personal computer or laptop"
	lab var Grid_M158_7M158	"M158  Presence of Household Conveniences:M158.g.  Washing machine"
	lab var Grid_M158_8M158	"M158  Presence of Household Conveniences:M158.h.  Refrigerator/Freezer"
	lab var Grid_M158_9M158	"M158  Presence of Household Conveniences:M158.i.  Air conditioner"
	lab var Grid_M158_10M158	"M158  Presence of Household Conveniences:M158.j.  CD/VCD/DVD Player"
	lab var Grid_M158_11M158	"M158  Presence of Household Conveniences:M158.k.  Component/Karaoke"
	lab var Grid_M158_12M158	"M158  Presence of Household Conveniences:M158.l.  Sala set"
	lab var Grid_M158_13M158	"M158  Presence of Household Conveniences:M158.m.  Dining set"
	lab var Grid_M158_14M158	"M158  Presence of Household Conveniences:M158.n.  Microwave oven"

	lab var Grid_M158_1M158_Quant	"M158  quantity:M158.a.  Radio"
	lab var Grid_M158_2M158_Quant	"M158  quantity:M158.b.  Television"
	lab var Grid_M158_3M158_Quant	"M158  quantity:M158.c.  VTR/VHS/VCD/DVD Player"
	lab var Grid_M158_4M158_Quant	"M158  quantity:M158.d.  Landline/Wireless phone"
	lab var Grid_M158_5M158_Quant	"M158  quantity:M158.e.  Cellular phone"
	lab var Grid_M158_6M158_Quant	"M158  quantity:M158.f.  Personal computer or laptop"
	lab var Grid_M158_7M158_Quant	"M158  quantity:M158.g.  Washing machine"
	lab var Grid_M158_8M158_Quant	"M158  quantity:M158.h.  Refrigerator/Freezer"
	lab var Grid_M158_9M158_Quant	"M158  quantity:M158.i.  Air conditioner"
	lab var Grid_M158_10M158_Quant	"M158  quantity:M158.j.  CD/VCD/DVD Player"
	lab var Grid_M158_11M158_Quant	"M158  quantity:M158.k.  Component/Karaoke"
	lab var Grid_M158_12M158_Quant	"M158  quantity:M158.l.  Sala set"
	lab var Grid_M158_13M158_Quant	"M158  quantity:M158.m.  Dining set"
	lab var Grid_M158_14M158_Quant	"M158  quantity:M158.n.  Microwave oven"

	lab var Grid_M159_1M159	"M159  Presence of Household Conveniences: M159.a. Car/truck, jeep, van"
	lab var Grid_M159_2M159	"M159  Presence of Household Conveniences: M159.b.  Motorcycle/Tricycle"
	lab var Grid_M159_3M159	"M159  Presence of Household Conveniences: M159.c.  Bicycle, Pedicab"
	lab var Grid_M159_4M159	"M159  Presence of Household Conveniences: M159.d.  Animal drawn cart"
	lab var Grid_M159_5M159	"M159  Presence of Household Conveniences: M159.e.  Tractor"
	lab var Grid_M159_6M159	"M159  Presence of Household Conveniences: M159.f.  Non-motorized boat or banca"
	lab var Grid_M159_7M159	"M159  Presence of Household Conveniences: M159.g.  Boat or banca with a motor"
	lab var Grid_M159_8M159	"M159  Presence of Household Conveniences: M159.h.  Electric fan"
	lab var Grid_M159_9M159	"M159  Presence of Household Conveniences: M159.h.  Other"

	lab var Grid_M159_1M159_Quant	"M159  quantity: M159.a. Car/truck, jeep, van"
	lab var Grid_M159_2M159_Quant	"M159  quantity: M159.b.  Motorcycle/Tricycle"
	lab var Grid_M159_3M159_Quant	"M159  quantity: M159.c.  Bicycle, Pedicab"
	lab var Grid_M159_4M159_Quant	"M159  quantity: M159.d.  Animal drawn cart"
	lab var Grid_M159_5M159_Quant	"M159  quantity: M159.e.  Tractor"
	lab var Grid_M159_6M159_Quant	"M159  quantity: M159.f.  Non-motorized boat or banca"
	lab var Grid_M159_7M159_Quant	"M159  quantity: M159.g.  Boat or banca with a motor"
	lab var Grid_M159_8M159_Quant	"M159  quantity: M159.h.  Electric fan"
	lab var Grid_M159_9M159_Quant	"M159  quantity: M159.h.  Other"

	lab var M160	"M160  Other Agricultural Land"

	lab var Grid_M161_1M161	"M161  Other Assets:M161.a.  Goat"
	lab var Grid_M161_2M161	"M161  Other Assets:M161.b.  Pig"
	lab var Grid_M161_3M161	"M161  Other Assets:M161.c.  Piglet"
	lab var Grid_M161_4M161	"M161  Other Assets:M161.d.  Cow"
	lab var Grid_M161_5M161	"M161  Other Assets:M161.e.  Carabao"
	lab var Grid_M161_6M161	"M161  Other Assets:M161.f.  Chicken"
	lab var Grid_M161_7M161	"M161  Other Assets:M161.g.  Rooster"
	lab var Grid_M161_8M161	"M161  Other Assets:M161.h.  Water pump"
	lab var Grid_M161_9M161	"M161  Other Assets:M161.i.  Thresher"
	lab var Grid_M161_10M161	"M161  Other Assets:M161.j.  Hand tractor"
	lab var Grid_M161_11M161	"M161  Other Assets:M161.k.  Irrigation equipment"
	lab var Grid_M161_12M161	"M161  Other Assets:M161.l.  Power saw"
	lab var Grid_M161_13M161	"M161  Other Assets:M161.m. Other assets, specify"
	lab var Grid_M161_14M161	"M161  Other Assets:M161.n.  Cat"
	lab var Grid_M161_15M161	"M161  Other Assets:M161.o.  Dog"
	lab var Grid_M161_16M161	"M161  Other Assets:M161.p.  Duck"
	lab var Grid_M161_17M161	"M161  Other Assets:M161.q.  Horse"
	lab var Grid_M161_18M161	"M161  Other Assets:M161.r.  Turkey"

	lab var N162	"N162  Materials of Roof"
	lab var N163	"N163  Materials of Walls"
	lab var N164	"N164  Materials of the Floor"
	lab var N165	"N165  Type of Building/ House"
	lab var N166	"N166  Number of Bedrooms"
	lab var N167	"N167  Tenure Status of Property Occupied"
	lab var N168	"N168  Source of Fuel for Lighting"
	lab var N169	"N169  Type of Fuel for Cooking "

	lab var Grid_N170_1N170	"N170  Location of Kitchen:N170.1.  Location of Kitchen - In the house"
	lab var Grid_N170_2N170	"N170  Location of Kitchen:N170.2.  Location of Kitchen - In a separate building"
	lab var Grid_N170_3N170	"N170  Location of Kitchen:N170.3   Location of Kitchen - Outdoors"

	lab var N171	"N171  Time Length to Get to the Nearest Telephone/Mobile Phone"
	lab var N172	"N172  Do you live in the poblacion? (SA)"
	lab var N173	"N173  Frequency of Travel to Poblacion"
	lab var N174	"N174  Amount of Fare to Poblacion"

	lab var M2 "HOUSEHOLD ID NO"


	*browse list of strings
		ds,has(type string)
		br `r(varlist)' 

	*drop string variables
		drop A02	A07_C_97	A09_C_6	A09_C_97	A10_C_4	B13a_C_3	B13b_C_3	B17_C_97	B21_C_97	B23_C_97	C24_C_13	C30_C_97	C33_C_97	C34_C_97	D41_C_12	D51	E61_C_11	E67_C_5	E68_C_97	F72a_C_97	F72b_C_97	F75a_C_97	F75b_C_97	F80_C_15	F81_C_4	F81_C_5	G84_C_97	G86_C_97	G89_C_4	G90_C_3	G91_C_97	G96_C_97	G98_C_97	G99_C_97	G100_C_97	G101_C_97	H108_C_97	K133	L148_C_97	L149_C_97	Grid_L157_1_8L157_1_Oth	Grid_M159_8M159_Oth	Grid_M161_13M161_Oth	N164_C_97	N168_C_97	N169_C_97	Grid_C32a_1C32a_Not	Grid_C32a_2C32a_Not	Grid_C32a_3C32a_Not	Grid_C32a_4C32a_Not	Grid_C32a_5C32a_Not	Grid_C32a_6C32a_Not	Grid_C32a_7C32a_Not	Grid_C32a_8C32a_Not	Grid_C32a_9C32a_Not	Grid_C32a_10C32a_Not	C33a_C_97	C34a_C_97	N164a_C_97

	*unknown variables
		drop M2_1 A02_1 B14a_C_997 B14b_C_997

	lab var	E53_C_1 "E53 Period of Owning Bank Account: months"
	lab var	E53_C_2 "E53 Period of Owning Bank Account: years"
	
	lab var E54_C_1 "E54  Amount of Money in all HH Bank Accounts: PHP"
	*drop empty variables
		missings dropvars,force

	lab var E57_C_1 "E57  Number of Loans for Payment: number of loans"
	lab var E58_C_1 "E58  Number of Loans Used for Toilet Facility: number of loans"
	lab var E63_C_1 "Amount borrowed PHP"
	lab var E65_C_1 "How much is the total interest over the course of the loan?: PHP"
	lab var E69_C_1	"E69  Days Obtaining the Loan:quantity"

	drop C32a_Intro1 Grid_C32a_1C32a Grid_C32a_2C32a Grid_C32a_3C32a Grid_C32a_4C32a Grid_C32a_5C32a Grid_C32a_6C32a Grid_C32a_7C32a Grid_C32a_8C32a Grid_C32a_9C32a Grid_C32a_10C32a C33a C34a
	drop N162a N163a N164a Picture Picture_YN M16T M16TXT M15M16_LOI D51_CODED

	lab var M16D "interview date"

	*browse list of strings
		ds,has(type string)
		br `r(varlist)' 

	local string_vars "H108 A09 B12d B23 C29 D40 E62 F80 F82 G91 G92 G95 G98 G99 G100 G102"

	*label the variables

	local var_name "A03"
		lab define ///
		`var_name'_lbl	///
			1 "Household Head" ///
			2 "Wife/ Spouse" ///
			3 "Son/ Daughter" ///
			4 "Brother/ Sister" ///
			5 "Son/ Daughter-in-law" ///
			6 "Grandson/ Granddaughter" ///
			7 "Father/ Mother" ///
			8 "Other Relative"

		lab val `var_name' `var_name'_lbl

		local var_name "A07"
			lab define ///
			`var_name'_lbl	///
				1 "Household Head" ///
				2 "Wife/Spouse" ///
				3 "Both Head and Wife/Spouse" ///
				4 "Child" ///
				9 "None" ///
				11 "Siblings" ///
				12 "Grandchildren" ///
				13 "Grandfather" ///
				14 "Grandmother" ///
				15 "Mother" ///
				16 "Niece/Nephew" ///
				17 "Cousin" ///
				18 "Aunt" ///
				19 "Daughter-in-law" ///
				20 "Mother-in-law" ///
				21 "Sister-in-law" ///
				22 "Son in-law" 


			lab val `var_name' `var_name'_lbl


		local var_name "A09"
			lab define ///
			`var_name'_lbl	///
				1 "Food " ///
				2 "Health/Medical care" ///
				3 "Education/Schooling/School materials" ///
				4 "Housing (rent, construction, or repairs)" ///
				5 "Clothing, shoes, and similar products" ///
				6 "Investment, specify" ///
				7 "Savings" ///
				8 "Coconut wine" ///
				9 "Eatery" ///
				10 "Feeds (poultry,hog,etc..)" ///
				11 "Native delicacies  (banana que,biko,bibingka,camote que)" ///
				12 "Piggery" ///
				13 "Rootcrop" ///
				14 "Sari-sari store" ///
				15 "Allowance" ///
				16 "Fare" ///
				17 "Fertilizer" ///
				18 "Household needs" ///
				19 "Loan payment" ///
				20 "Lot/land payment" ///
				21 "Processing fee for live birth" ///
				99 "No longer receive grants" 

			split A09,parse(,)
			destring A091 A092 A093 A094 A095 A096 A097,replace
			lab val A091 A092 A093 A094 A095 A096 A097 `var_name'_lbl

		lab var A091 "A09  Expenditures Last Pantawid Grant Used On"
		lab var A092 "A09  Expenditures Last Pantawid Grant Used On"
		lab var A093 "A09  Expenditures Last Pantawid Grant Used On"
		lab var A094 "A09  Expenditures Last Pantawid Grant Used On"
		lab var A095 "A09  Expenditures Last Pantawid Grant Used On"
		lab var A096 "A09  Expenditures Last Pantawid Grant Used On"
		lab var A097 "A09  Expenditures Last Pantawid Grant Used On"


		local var_name "A10"
			lab define ///
			`var_name'_lbl	///
				1 "ATM card/ Cash card " ///
				2 "Over-the-counter (OTC)" ///
				3 "Off-site payment" ///
				5 "Gcash" ///
				6 "Cash" ///
				7 "Payroll" ///
				99 "No longer receive grants" 
			lab val `var_name' `var_name'_lbl

		local var_name "B12a"
			lab define ///
			`var_name'_lbl	///
				1 "Piped into dwelling" ///
				2 "Piped into yard/plot" ///
				3 "Public tap/Standpipe" ///
				4 "Protected well" ///
				5 "Unprotected well" ///
				6 "Protected spring" ///
				7 "Unprotected spring (natural form)" ///
				8 "TUBE WELL OR BOREHOLE" ///
				9 "RAINWATER" ///
				10 "TANKER TRUCK" ///
				12 "SURFACE WATER (river, dam, lake, pond, stream, canal, irrigation channel)" ///
				13 "BOTTLED WATER" ///
				99 "NONE"
			lab val `var_name' `var_name'_lbl

		lab define yes_no 1 "yes" 2 "no"
		destring B12b,replace
		lab val B12b yes_no

		lab val B12c B12a_lbl
		destring B12d1 B12d2 B12d3,replace
		lab val B12d1 B12d2 B12d3 B12a_lbl


		local var_name "B13a"
			lab define ///
			`var_name'_lbl	///
				1 "In own dwelling" ///
				2 "In own yard/ plot" ///
				3 "Elsewhere, specify" ///
				4 "Buy at the store / sari-sari store" ///
				5 "Beside the street" ///
				7 "In neighbor's house" ///
				8 "Water refilling station" ///
				9 "Public tap/Standpipe" ///
				10 "In relative's house" ///
				11 "Water from spring" ///
				12 "Surface water (river, dam, lake, pond, stream, canal, irrigation channel)" ///
				14 "At the church" ///
				15 "At the farm (banana,coconut,etc.)" ///
				16 "In other barangay" ///
				17 "Near barangay hall" ///
				18 "Near basketball court" ///
				19 "Near school" ///
				20 "Near tennis court" ///
				21 "Near the river" ///
				22 "Near the creek" ///
				23 "Near the highway" ///
				24 "Near gasoline station" ///
				25 "Near the house of barangay captain" ///
				26 "In the mountain" ///
				27 "In neighbor's yard / plot" ///
				28 "Near the camp" ///
				33 "Proper Poblacion" ///
				38 "5 meters away from home" ///
				39 "15meters away  from home" ///
				40 "10 meters away  from home" ///
				41 "25 meters away  from home" ///
				43 "70 meters away  from home" ///
				44 "100 meters away  from home" ///
				45 "500 meters away  from home" 
			lab val `var_name' `var_name'_lbl

		lab val B13b B13a_lbl
	

		local var_name "B14a"
			lab define ///
			`var_name'_lbl	///
				000 "Not applicable – delivered water " ///
				996 "Not applicable – own dwelling" 
			lab val `var_name' `var_name'_lbl

		lab val B14b B13a_lbl

		lab val B15 yes_no
		lab val B18 yes_no
		lab val B20 yes_no

		local var_name "B17"
			lab define ///
			`var_name'_lbl	///
				1 "Per use " ///
				2 "Annually " ///
				3 "Monthly" ///
				4 "Weekly" ///
				5 "Everyday" ///
				6 "Every 2 days" ///
				7 "Every 3 days" ///
				8 "Every 4 days" ///
				9 "Every 15 days" ///
				10 "Twice a month / Every 2 weeks" ///
				11 "Every 3 months" ///
				12 "Every 6 months" ///
				13 "Twice in a week" ///
				14 "Thrice every week" ///
				15 "Once in 2 months" ///
				16 "3x a year" 
			lab val `var_name' `var_name'_lbl

		local var_name "B19"
			lab define ///
			`var_name'_lbl	///
				1 "Wide-mouthed Container (a hand can fit through the opening)" ///
				2 "Narrow-mouthed Container (a hand CANNOT fit through the opening)" 
			lab val `var_name' `var_name'_lbl

		local var_name "B21"
			lab define ///
			`var_name'_lbl	///
				1 "Using a dipper/ shared utensil" ///
				2 "Turning/Pressing a spout on the container" ///
				3 "Using pitcher" ///
				4 "Pour directly in a glass" ///
				5 "Using water dispenser" 
			lab val `var_name' `var_name'_lbl


		local var_name "B22"
			lab define ///
			`var_name'_lbl	///
				1 "Yes, for all household member" ///
				2 "Yes, for certain household members (e.g., small kids only)" ///
				3 "No" 
			lab val `var_name' `var_name'_lbl



		local var_name "B23"
			lab define ///
			`var_name'_lbl	///
				1 "Boiling the water" ///
				2 "Adding chlorine/bleach" ///
				3 "Adding iodine" ///
				4 "Solar disinfection" ///
				5 "Filter (mechanical/ceramic/sand/etc)" ///
				6 "Strain through cloth" ///
				7 "Let it stand and settle" ///
				8 "Cover the container well" ///
				10 "Wash the container thoroughly" ///
				99 "None" 
			lab val B231 B232 B233 B234 B235 B236 B237 `var_name'_lbl

		local var_name "C24"
			lab define ///
			`var_name'_lbl	///
				0 "No facility/Bush/Field" ///
				2 "Flush to septic tank" ///
				3 "Flush to pit toilet" ///
				5 "Flush to don't know where" ///
				6 "Ventilated pit toilet" ///
				7 "Pit toilet with slab" ///
				8 "Pit toilet without slab/open pit" ///
				9 "Composting toilet" ///
				10 "Bucket toilet" ///
				11 "Drop type/Overhang type" ///
				12 "Public Toilet" 
			lab val `var_name' `var_name'_lbl


		lab val C25 yes_no

		local var_name "C26"
			lab define ///
			`var_name'_lbl	///
				1 "Inside the house" ///
				2 "Outside the house" 
			lab val `var_name' `var_name'_lbl


		local var_name "C27"
			lab define ///
			`var_name'_lbl	///
				1 "2014 or earlier" ///
				2 "(2015)" ///
				3 "(2016)" ///
				4 "Last year/ 2017" ///
				5 "This year/ 2018"
			lab val `var_name' `var_name'_lbl


		local var_name "C28"
			lab define ///
			`var_name'_lbl	///
				0 "Free" ///
				1 "Below Php 5,000" ///
				2 "Php 5000 to Php 10,000" ///
				3 "More than Php 10,000" 
			lab val `var_name' `var_name'_lbl



		local var_name "C29"
			lab define ///
			`var_name'_lbl	///
				1 "Own money" ///
				2 "Loan from family/relatives" ///
				3 "Grant from Government (LGU/DSWD)" ///
				4 "Grant from NGO" ///
				5 "Loan from Microfinance Institutions" 
			lab val C291 C292 C293 `var_name'_lbl


		local var_name "C30"
			lab define ///
			`var_name'_lbl	///
				1 "Packed mud/earth" ///
				2 "Ceramic/Vinyl" ///
				3 "Wooden" ///
				4 "Plastic slab" ///
				5 "Cement slab" ///
				6 "Sack of sand" ///
				7 "File of stone" ///
				8 "Sand" ///
				99 "No flooring" 
			lab val `var_name' `var_name'_lbl

		lab val C31 yes_no
		lab val Grid_C32_1C32 Grid_C32_2C32 Grid_C32_3C32 Grid_C32_4C32 Grid_C32_5C32 Grid_C32_6C32 Grid_C32_7C32 Grid_C32_8C32 Grid_C32_9C32 Grid_C32_10C32 yes_no


		local var_name "C33"
			lab define ///
			`var_name'_lbl	///
				0 "No roof  " ///
				1 "Concrete  " ///
				2 "Iron sheets  " ///
				3 "Wood " ///
				4 "Grass " ///
				5 "Plastic sheets  " ///
				6 "Salvaged materials  " ///
				8 "Anahaw " ///
				9 "Bamboo " ///
				10 "Bamboo woven mats (amakan) " ///
				11 "Coco leaves " ///
				12 "Curtain " ///
				14 "Lona " ///
				15 "Nipa " ///
				16 "Sack " ///
				17 "Tarpaulin " ///
				18 "Iron sheets and nipa " 
			lab val `var_name' `var_name'_lbl

	
		local var_name "C34"
			lab define ///
			`var_name'_lbl	///
				1 "Concrete " ///
				2 "Iron sheets " ///
				3 "Wood" ///
				4 "Grass" ///
				5 "Plastic sheets " ///
				6 "Salvaged materials " ///
				7 "Bamboo" ///
				8 "Bamboo and iron sheets" ///
				9 "Bamboo and curtain" ///
				10 "Bamboo and woven plastic" ///
				11 "Bamboo woven mats (amakan)" ///
				12 "Bamboo woven mats and bamboo" ///
				13 "Bamboo woven mats and iron sheets" ///
				14 "Bamboo woven mats and nipa" ///
				15 "Bamboo woven mats and plywood" ///
				16 "Bamboo woven mats and sack" ///
				18 "Buri leaves" ///
				19 "Cement and bamboo" ///
				20 "Cement and bamboo woven mats" ///
				21 "Cement and coco lumber" ///
				22 "Cement and hardiflex" ///
				23 "Cement and iron sheets" ///
				25 "Cement and lona" ///
				26 "Cement and plastic sheets" ///
				27 "Cement and plywood" ///
				28 "Cement,plywood and iron sheets" ///
				29 "Cement and sack" ///
				30 "Cement and wood" ///
				31 "Cloth" ///
				32 "Cloth and iron sheets" ///
				33 "Coconut leaves" ///
				34 "Coco lumber" ///
				36 "Curtain" ///
				37 "Floormat" ///
				38 "Hardiplex" ///
				39 "Hardiflex and hollow blocks" ///
				40 "Hardiplex and iron sheets" ///
				41 "Hollow blocks" ///
				42 "Hollow blocks and bamboo" ///
				43 "Hollow blocks and bamboo woven mats" ///
				44 "Hollow blocks and lona" ///
				45 "Hollow blocks and plywood" ///
				46 "Hollow blocks and iron sheets" ///
				47 "Hollow blocks and sack" ///
				48 "Hollow blocks and tarpauline" ///
				49 "Lona" ///
				50 "Lona and iron sheets" ///
				51 "Lona and plywood" ///
				53 "Nipa" ///
				54 "Nipa and bamboo" ///
				55 "Nipa,bamboo woven mats and sack" ///
				56 "Nipa,hardiflex and lona" ///
				57 "Nipa and iron sheets" ///
				58 "Nipa and sack" ///
				59 "Plywood" ///
				60 "Plywood and bamboo" ///
				61 "Plywood,bamboo and iron sheets" ///
				62 "Plywood and coconut leaves" ///
				63 "Plywood and iron sheets" ///
				64 "Plywood,iron sheets and lona" ///
				65 "Plywood and nipa" ///
				66 "Plywood and sack" ///
				67 "Sack" ///
				68 "Sack and bamboo" ///
				69 "Sack,carpet,lona and iron sheets" ///
				70 "Sack and floormat" ///
				71 "Sack and iron sheets" ///
				72 "Sack and lona" ///
				73 "Sack and wood" ///
				74 "Shower curtain" ///
				75 "Tanner bag" ///
				76 "Tarpaulin" ///
				77 "Tiles" ///
				78 "Wood planks (tabla)" ///
				79 "Wood planks and curtain" ///
				80 "Wood planks and hollow blocks" ///
				81 "Wood and lona" 

			lab val `var_name' `var_name'_lbl

		local var_name "C35"
			lab define ///
			`var_name'_lbl	///
				1 "Yes, many " ///
				2 "Some or few " ///
				3 "None" 
			lab val `var_name' `var_name'_lbl

		lab val C36 C38 yes_no

		local var_name "C37"
			lab define ///
			`var_name'_lbl	///
				1 "Yes, soap" ///
				2 "Yes, water" ///
				3 "Yes, both soap and water" ///
				4 "No soap and water" 
			lab val `var_name' `var_name'_lbl

	
		local var_name "C39"
			lab define ///
			`var_name'_lbl	///
				4 "Very satisfied" ///
				3 "Somewhat satisfied" ///
				2 "Somewhat dissatisfied" ///
				1 "Very dissatisfied	" 
			lab val `var_name' `var_name'_lbl


	
		local var_name "D40"
			lab define ///
			`var_name'_lbl	///
					0 "None" ///
					1 "Drink safe water" ///
					2 "Use a toilet facility" ///
					3 "Improve/upgrade the toilet facility" ///
					4 "Wash hands/face/body" ///
					5 "Food hygiene" ///
					6 "Keep the environment clean" ///
					7 "Put chlorine in toilet bowl" 
			lab val D401 D402 D403 D404 D405 D406 D407 `var_name'_lbl

	
		local var_name "D41"
			lab define ///
			`var_name'_lbl	///
					1 "Neighbors/family" ///
					2 "Barangay official" ///
					3 "Municipal Link" ///
					4 "Public Health Office (MHO, BHW)" ///
					5 "School/Teacher" ///
					6 "Religious leader" ///
					7 "Television" ///
					8 "Radio" ///
					9 "SMS" ///
					10 "NGO" ///
					11 "Parent Leader" ///
					13 "Own initiative" ///
					14 "CSO" ///
					15 "Red cross" ///
					16 "Oxfam" ///
					17 "DSWD" 
			lab val `var_name' `var_name'_lbl


	
		local var_name "D42"
			lab define ///
			`var_name'_lbl	///
				1 "More than 1 year ago" ///
				2 "More than 6 months, but less than 1 year ago" ///
				3 "More than 3 months, but less than 6 months ago" ///
				4 "Less than 3 months ago" 
			lab val `var_name' `var_name'_lbl


	
		local var_name "D43"
			lab define ///
			`var_name'_lbl	///
				1 "Always" ///
				2 "Sometimes " ///
				3 "Never" ///
				4 "I’m not familiar with the FDS" 

			lab val `var_name' `var_name'_lbl


		lab val D44a D44b yes_no

		local var_name "D45a"
			lab define ///
			`var_name'_lbl	///
				1 "More than 1 year ago" ///
				2 "More than 6 months, but less than 1 year ago" ///
				3 "More than 3 months, but less than 6 months ago" ///
				4 "Less than 3 months ago" ///
				9 "Cannot remember " 

			lab val `var_name' D45b `var_name'_lbl

	
		local var_name "D46a"
			lab define ///
			`var_name'_lbl	///
				1 "Municipal Link" ///
				2 "Rural Sanitary Inspector" ///
				3 "Municipal Health Officer" ///
				4 "Parent Leader" ///
				5 "Barangay Official" 

			lab val `var_name' D46b `var_name'_lbl


		local var_name "Grid_D47_1D47"
			lab define ///
			`var_name'_lbl	///
				1 "Very Satisfied" ///
				2 "Satisfied" ///
				3 "Neither satisfied nor dissatisfied" ///
				4 "Dissatisfied" ///
				5 "Very Dissatisfied" 

			lab val `var_name' Grid_D47_2D47 Grid_D50_1D50 `var_name'_lbl

		lab val Grid_D48_1D48 Grid_D48_2D48 Grid_D48_3D48 Grid_D48_4D48 Grid_D48_5D48 D48_1 D49 yes_no
		lab val Grid_E52_1E52 Grid_E52_2E52 Grid_E52_3E52 yes_no

		local var_name "E53"
			lab define ///
			`var_name'_lbl	///
				9999 "Don't Know" ///
				9998 "Refused" 

			lab val `var_name' E54 E57 E58 E63 E66 E69 E70 F76a F76b F78a F78b `var_name'_lbl

		lab val E55 E56 E64 Grid_F71_1F71 Grid_F71_2F71 F77b yes_no

		local var_name "E59"
			lab define ///
			`var_name'_lbl	///
				1 "Household Head" ///
				2 "Wife/Spouse" ///
				3 "Son/Daughter" ///
				4 "Brother/Sister" ///
				5 "Son/Daughter-in-law" ///
				6 "Grandson/granddaughter" ///
				7 "ather/Mother" ///
				8 "Other Relative" 

			lab val `var_name' `var_name'_lbl

		local var_name "E60"
			lab define ///
			`var_name'_lbl	///
				1 "Before 2015" ///
				2 "(2015)" ///
				3 "(2016)" ///
				4 "(2017)" ///
				5 "(2018)" 

		lab val `var_name' `var_name'_lbl

		local var_name "E61"
			lab define ///
			`var_name'_lbl	///
				1 "Relatives/Friends " ///
				2 "Agricultural Development Bank" ///
				3 "Commercial Bank" ///
				4 "Microfinance Institution" ///
				5 "Other finance institution" ///
				6 "NGO Relief Agency " ///
				7 "Landlord/Employer" ///
				8 "Shopkeeper" ///
				9 "Money Lender " ///
				10 "Cooperative" ///
				12 "Farmers Association" ///
				13 "Social Security System (SSS)" ///
				14 "Sustainable Livelihood Program (SLP)" ///
				15 "Sinking fund" ///
				16 "Land bank" ///
				17 "CRBC Central Rural Bank" 

		lab val `var_name' `var_name'_lbl


		local var_name "E62"
			lab define ///
			`var_name'_lbl	///
				1 "Purchase of inputs (fertilizers, seeds, insecticides, etc.)" ///
				2 "Purchase of equipment" ///
				3 "Purchase of land" ///
				4 "Purchase of livestock" ///
				5 "Building improvements for business" ///
				6 "Other business or farm use" ///
				7 "Household consumption needs" ///
				8 "Purchase/improvement of dwelling" ///
				9 "Marriage/family events" ///
				10 "Consumer durables" ///
				11 "For placement fees and other expenses for overseas work" ///
				12 "Other personal use (e.g. medical treatment, education, etc)" 

		lab val E621 E622 E623 E624 E625 E626 `var_name'_lbl

		local var_name "E67"
			lab define ///
			`var_name'_lbl	///
					1  "Daily" ///
					2  "Weekly" ///
					3  "Monthly" ///
					4  "Annually" ///
					6  "Every 15th" ///
					7  "Every 2 months" ///
					8  "One time payment" 

		lab val `var_name' `var_name'_lbl


		local var_name "E68"
			lab define ///
			`var_name'_lbl	///
				0 "No collateral" ///
				1 "Agricultural land" ///
				2 "Buildings or other property" ///
				3 "Gold/Silver" ///
				4 "Personal guarantee" ///
				5 "Past borrowing record" ///
				6 "Motor/Car/Tricycle/Boat" ///
				7 "Appliances" ///
				8 "Guarantor / Co-maker" ///
				9 "Salary" ///
				10 "Pig" 

		lab val `var_name' `var_name'_lbl

		local var_name "F72a"
			lab define ///
			`var_name'_lbl	///
				1 "Household member " ///
				2 "General Laborer" ///
				3 "Mason/ with experience in toilet construction – Skilled Worker" ///
				4 "Neighbor/ Relatives/ Friends (not a HH member)" ///
				5 "Laborer grant by NHA" ///
				6 "Laborer grant by Caritas" ///
				7 "Laborer grant by Red Cross" 

		lab val `var_name' F72b `var_name'_lbl

		lab val F74a F74b F77a yes_no

		local var_name "F75a"
			lab define ///
			`var_name'_lbl	///
				1 "Relatives/Friends" ///
				2 "Agricultural Development Bank" ///
				3 "Commercial Bank" ///
				4 "Microfinance Institution " ///
				5 "Other finance institution" ///
				6 "NGO Relief Agency" ///
				7 "Landlord/Employer" ///
				8 "Shopkeeper" ///
				9 "Money Lender" ///
				10 "Cooperative" ///
				13 "Social Security System (SSS)" 

		lab val `var_name' F75b `var_name'_lbl

		local var_name "F79"
			lab define ///
			`var_name'_lbl	///
				1 "Mason/local craftsman" ///
				2 "Local vendors" ///
				3 "Neighbors/Family" ///
				4 "Barangay official " ///
				5 "Municipal Link" ///
				6 "Barangay Health Worker" 

		lab val `var_name' `var_name'_lbl

		local var_name "F80"
			lab define ///
			`var_name'_lbl	///
				1 "Improved hygiene/cleanliness" ///
				2 "More privacy" ///
				3 "Convenience/saves time" ///
				4 "Improved status/prestige" ///
				5 "Improved health" ///
				6 "More comfortable" ///
				7 "Improved safety" ///
				8 "Social pressure" ///
				9 "Enforcement of government" ///
				10 "CLTS/ FDS/ triggering / mapping of sanitation situations" ///
				11 "Subsidy on offer" ///
				12 "Had enough money to buy" ///
				13 "Construction of new house" ///
				14 "Event/wedding/funeral/visitors from outside coming" 

		lab val F801 F802 F803 `var_name'_lbl


		local var_name "F81"
			lab define ///
			`var_name'_lbl	///
				1 "Head of household" ///
				2 "Wife/spouse " ///
				3 "Children" ///
				4 "Other members of the household (specify)" ///
				5 "Person outside the household (specify)" ///
				6 "Mother" ///
				7 "Father" ///
				8 "Local Government Unit (LGU)" ///
				9 "Non Goverment Organization (NGO)" ///
				10 "National Housing Authority (NHA)" ///
				11 "Red cross" 

		lab val `var_name' `var_name'_lbl


		local var_name "F82"
			lab define ///
			`var_name'_lbl	///
				1 "High cost/unaffordable" ///
				2 "Competing priorities" ///
				3 "Nobody to build/install it" ///
				4 "Materials not available" ///
				5 "Geological limitations (e.g. water table/soil conditions/regular flooding)" ///
				6 "Limited space" ///
				7 "Legal/Tenancy issues (no title, renting, other's house, permit problems)" ///
				8 "Dislike available toilet options" ///
				9 "There are no constraints to improving the toilet facility" 

		lab val F821 F822 F823 `var_name'_lbl


		lab val G83 yes_no


		local var_name "G84"
			lab define ///
			`var_name'_lbl	///
				1  "ASA Philippines through a group orientation" ///
				2  "ASA Philippines through a one-on-one orientation" ///
				3  "Municipal Link" ///
				4  "Co-members in the ASA group" ///
				5  "World bank" ///
				7  "Neighbor" ///
				98  "Don't Know/Can't Recall" 

		lab val `var_name' `var_name'_lbl


		local var_name "G85"
			lab define ///
			`var_name'_lbl	///
				4 "Yes, all of it" ///
				3 "I understood most of it" ///
				2 "I did not understand most of it" ///
				1 "No, I did not understand any of it" 

		lab val `var_name' `var_name'_lbl

		destring G86 G87 G88,replace

		local var_name "G86"
			lab define ///
			`var_name'_lbl	///
				1  "Amount of loan or household counterpart" ///
				2  "Amount of discount (subsidy)" ///
				3  "The repayment terms (weekly payment, attendance in group meetings, etc)" ///
				4  "The application process" ///
				5  "The disbursement terms (release of 50% as downpayment to the mason, etc)" ///
				6  "Interest rate" ///
				99  "None" 

		lab val `var_name' `var_name'_lbl


		local var_name "G89"
			lab define ///
			`var_name'_lbl	///
				1 "Household Head" ///
				2 "Wife/Spouse" ///
				3 "Joint decision (HH and wife/spouse)" ///
				4 "Other family members (specify)" ///
				5 "Children" ///
				6 "Parents" ///
				7 "Grandmother" 

		lab val `var_name' `var_name'_lbl

		local var_name "G90"
			lab define ///
			`var_name'_lbl	///
				1 "Construction of new toilet" ///
				2 "Repair or improvement of toilet" ///
				6 "For business" ///
				7 "For education" ///
				9 "For household expenses" ///
				10 "For personal needs" ///
				11 "House repair" 

		lab val `var_name' `var_name'_lbl



		local var_name "G91"
			lab define ///
			`var_name'_lbl	///
				1 "I want my family to experience the convenience of using own toilet" ///
				2 "I want to protect my family from illnesses brought about by open defecation" ///
				3 "I was receiving pressure from my neighbors to have own toilet built" ///
				4 "I was forced by my Municipal Link" ///
				5 "I was convinced by ASA to loan to have our own toilet built" 
			
		lab val G911 G912 G913 G914 `var_name'_lbl


		local var_name "G92"
			lab define ///
			`var_name'_lbl	///
				1 "We no longer defecate in the open" ///
				2 "We don’t have to use shared toilet" 
			
		lab val G921 G922 G923 `var_name'_lbl


	lab define label_acceptable ///
		5 "Very acceptable" ///
		4 "Acceptable" ///
		3 "Can’t say" ///
		2 "Unacceptable" ///
		1 "Very unacceptable" 
	lab val Grid_G93_1G93 Grid_G93_2G93 Grid_G93_3G93 Grid_G93_4G93 Grid_G93_5G93 Grid_G93_6G93 Grid_G93_7G93 Grid_G93_8G93 Grid_G93_9G93 label_acceptable

		lab val G94 yes_no
	
	
			local var_name "G95"
				lab define ///
				`var_name'_lbl	///
					1 "From salary or income of HH Head" ///
				2 "From the Pantawid cash grant" ///
				3 "From income of our business" ///
				4 "From our savings" ///
				5 "From salary or income of other household members " 

		lab val G951 G952 G953 `var_name'_lbl


		local var_name "G96"
			lab define ///
			`var_name'_lbl	///
				1 " used the money for our daily needs (food, etc)" ///
				2 " used the money for an emergency (illness, accident, etc)" ///
				3 " used the money for a family event (baptism, birthday, fiesta, etc)" ///
				4 " used the money for another purpose (specify)" ///
				5 "ncome was not sufficient " ///
				6 " forgot my due date" ///
				7 " didn't continue to loan at ASA" ///
				8 "hen I receive the Ph5000.00 I returned  right away the amount of Php2500.00"

		lab val `var_name' `var_name'_lbl

		lab val G97 yes_no

		local var_name "G98"
			lab define ///
			`var_name'_lbl	///
				1 "We missed one or several meals" ///
				2 "We reduced household spending" ///
				3 "We used our savings intended for another purpose" ///
				4 "Accept laundry" ///
				5 "Selling fish" ///
				6 "Raising hogs /pig" ///
				7 "My husband applied on construction" ///
				999 "Don’t have any sacrifices/None" 

		lab val G981 G982 `var_name'_lbl

		local var_name "G99"
			lab define ///
			`var_name'_lbl	///
				1 "I already have a toilet" ///
				2 "I did not want to borrow" ///
				3 "I did not know all about a loan from ASA Philippines" ///
				4 "ASA Philippines did not approve my application" ///
				5 "I don’t have the capacity to repay the loan" ///
				6 "I don’t find the terms and conditions acceptable" ///
				7 "I was discouraged by family members" ///
				8 "Land owner didn't permit us to build a toilet" ///
				9 "No one offers  to me" ///
				10 "Late in submission of form" ///
				11 "We are for house relocation" ///
				12 "ASA didn't come back  in our place" 

		lab val G991 G992 G993 G994 `var_name'_lbl



		local var_name "G100"
			lab define ///
			`var_name'_lbl	///
				1 "Amount that I have to pay back (amount of Pantawid household counterpart)" ///
				2 "I have to pay weekly" ///
				3 "I have to attend center meetings" ///
				4 "I have to pay back in 6 or 12 months only" ///
				5 "Accredited masons who have to construct the toilet" ///
				6 "The quality of materials that will be used for the toilet" ///
				7 "Did not  borrow money to ASA" 

		lab val G1001 G1002 G1003 G1004 `var_name'_lbl



		local var_name "G101"
			lab define ///
			`var_name'_lbl	///
				1 "Build or strengthen the roof" ///
				2 "Build or strengthen the walls" ///
				3 "Put a door" ///
				4 "Improve the flooring (put tiles, etc)" ///
				5 "Replace the toilet bowl" 

		lab val `var_name' `var_name'_lbl



		local var_name "G102"
			lab define ///
			`var_name'_lbl	///
				1 "It is now more convenient or comfortable to use" ///
				2 "It is now more secure" ///
				3 "It is now sturdier and can withstand bad weather condition" 

		lab val G1021 G1022 G1023 `var_name'_lbl

	lab define label_5 ///
		5 "Very important " ///
		4 "Somewhat important" ///
		3 "Can't say if important or not " ///
		2 "Somewhat not important" ///
		1 "Not important at all " 
	lab val G103 label_5

		local var_name "H104"
			lab define ///
			`var_name'_lbl	///
				5 "Very satisfied " ///
				4 "Satisfied" ///
				3 "Neither satisfied nor dissatisfied" ///
				2 "Dissatisfied " ///
				1 "Very dissatisfied " 

		lab val `var_name' `var_name'_lbl

	lab val Grid_H105_1H105 Grid_H105_2H105 Grid_H105_3H105 H106 H107 yes_no

		local var_name "H108"
			lab define ///
			`var_name'_lbl	///
				1 "The materials used were of poor quality" ///
				2 "I have problems with flushing the toilet" ///
				3 "I have problems with the septic tank" ///
				4 "The walls are dilapidated" ///
				5 "The exhaust is not functional" 

		lab val H1081 H1082 H1083 `var_name'_lbl

	lab val Grid_H109_1H109 Grid_H109_2H109 H110 H112 H113 yes_no

		local var_name "H111"
			lab define ///
			`var_name'_lbl	///
				1 "Municipal Link" ///
				2 "Parent Leader" ///
				3 "ASA Branch" 

		lab val `var_name' `var_name'_lbl

		local var_name "H114"
			lab define ///
			`var_name'_lbl	///
				4 "Their conduct and behavior are appropriate all the time" ///
				3 "Their conduct and behavior are appropriate most of the time" ///
				2 "Their conduct and behavior are inappropriate most the time" ///
				1 "Their conduct and behavior are inappropriate all the time" 

		lab val `var_name' `var_name'_lbl


		local var_name "H115"
			lab define ///
			`var_name'_lbl	///
				4 "Much influence " ///
				3 "Some influence " ///
				2 "Little influence " ///
				1 "No influence at all " 

		lab val `var_name' `var_name'_lbl


		local var_name "H116"
			lab define ///
			`var_name'_lbl	///
				5 "Very important " ///
				4 "Somewhat important " ///
				3 "Can't say if important or not" ///
				2 "Somewhat not important " ///
				1 "Not important at all " 
				
		lab val `var_name' `var_name'_lbl


		local var_name "H117"
			lab define ///
			`var_name'_lbl	///
				5 "Much better now " ///
				4 "Somewhat better now " ///
				3 "The same " ///
				2 "Somewhat worse now " ///
				1 "Much worse now "
				
		lab val `var_name' `var_name'_lbl

		local var_name "H118"
			lab define ///
			`var_name'_lbl	///
				5 "Contributed very much " ///
				4 "Contributed much " ///
				3 "Contributed somewhat " ///
				2 "Contributed little " ///
				1 "Did not contribute at all (better QoL is because of other factors) " 
				
		lab val `var_name' `var_name'_lbl

		local var_name "H119"
			lab define ///
			`var_name'_lbl	///
				5 "Most or all of them " ///
				4 "Many of them " ///
				3 "Some of them " ///
				2 "A few of them " ///
				1 "None of them " 
				
		lab val `var_name' `var_name'_lbl

		local var_name "H120"
			lab define ///
			`var_name'_lbl	///
				1 "We intend to have a new toilet constructed " ///
				2 "We intend to improve our toilet" ///
				3 "We intend to repair our toilet" ///
				4 "No plan regarding toilet" 
				
		lab val `var_name' `var_name'_lbl


		local var_name "H121"
			lab define ///
			`var_name'_lbl	///
				1 "More budget on prevention (e.g., building toilets)" ///
				2 "More budget on cure (e.g., buying medicines) for sanitation-related illness and diseases" 
				
		lab val `var_name' `var_name'_lbl

		lab val Grid_I122_1I122 Grid_I122_2I122 Grid_I122_3I122 Grid_I122_4I122 Grid_I123_1I123 Grid_I123_2I123 yes_no

	label define reported_coverage_lbl 5 "All of us" 4 "Most of us" 3 "Some of us" 2 "Few of us" 1 "None of us"
	lab val Grid_I124_1I124 Grid_I124_2I124 Grid_I124_3I124 Grid_I124_4I124 reported_coverage_lbl

		local var_name "i125"
			lab define ///
			`var_name'_lbl	///
				3 "More of us practice this now" ///
				2 "Less of us practice this now" ///
				1 "No change " 

		lab val Grid_I125_1I125 Grid_I125_2I125 Grid_I125_3I125 Grid_I125_4I125 `var_name'_lbl


	lab val Grid_I126_1I126 Grid_I126_2I126 Grid_I126_3I126 Grid_I126_4I126 yes_no
	lab val I127 H116_lbl

		local var_name "I129"
			lab define ///
			`var_name'_lbl	///
				1 "Save for it " ///
				2 "Borrow from relatives/ friends " ///
				3 "Borrow from financial/ lending institutions" ///
				4 "Look for grants/ programs from government " ///
				5 "Look for grants/ programs from NGOs " 

		lab val `var_name' `var_name'_lbl

	lab define label_7 ///
		5 "Very likely" ///
		4 "Somewhat likely" ///
		3 "Neither likely or unlikely" ///
		2 "Somewhat unlikely" ///
		1 "Very unlikely" 
	lab val I130 label_7
		
		local var_name "K135"
			lab define ///
			`var_name'_lbl	///
				1 "Male " ///
				2 "Female" 

		lab val `var_name' `var_name'_lbl

		local var_name "K136"
			lab define ///
			`var_name'_lbl	///
				1 "Single" ///
				2 "Married/Living together" ///
				3 "Widowed" ///
				4 "Divorce/Separated" ///
				5 "Unknown" 
				
		lab val `var_name' `var_name'_lbl

		local var_name "K137"
			lab define ///
			`var_name'_lbl	///
				0 "No grade completed" ///
				1 "No grade completed" ///
				2 "Preschool" ///
				3 "Elementary level" ///
				4 "Elementary graduate" ///
				5 "High school level" ///
				6 "High school graduate" ///
				7 "Vocational level/graduate" ///
				8 "College level" ///
				9 "College graduate" ///
				10 "Post-graduate level/graduate" 
				
		lab val `var_name' `var_name'_lbl


		local var_name "K138"
			lab define ///
			`var_name'_lbl	///
				0 "Special occupations" ///
				1 "Government Officials, Managers or Proprietors, Supervisors" ///
				2 "Professionals" ///
				3 "Technicians and Associate Professionals" ///
				4 "Clerks" ///
				5 "Service Workers and Shop and Market Sales Workers" ///
				6 "Farmers, Forestry Workers and Fishermen" ///
				7 "Trades and Related Workers" ///
				8 " Plant and Machine Operators and Assemblers" ///
				9 "Laborers and Unskilled Workers (including vending, selling delicacies, making charcoal/ pag-uuling, running a sari-sari store, etc.)" ///
				10 " None"
				
		lab val `var_name' `var_name'_lbl


		local var_name "K139"
			lab define ///
			`var_name'_lbl	///
				1 "English" ///
				2 "Tagalog" ///
				3 "Cebuano" ///
				4 "Waray" ///
				5 "Ilonggo/ Hiligaynon" 
				
		lab val `var_name' `var_name'_lbl

		lab val K140 yes_no

		local var_name "E53"
		lab val L143 L144 L145 L146 L151 `var_name'_lbl

		local var_name "L147"
			lab define ///
			`var_name'_lbl	///
				1 "Permanent job/business/unpaid family work" ///
				2 "Short term or seasonal or casual job/business/unpaid family work" ///
				3 "Worked for different employer on day-to-day or week-to-week basis" 
				
		lab val `var_name' `var_name'_lbl


		local var_name "L148"
			lab define ///
			`var_name'_lbl	///
				1 "Works for private household" ///
				2 "Works for private establishment" ///
				3 "Worked for government/government corporation" ///
				4 "Self-employed without any paid employee" ///
				5 "Employer in own family-operated farm or business" ///
				6 "Worked with pay in own family-operated farm or business" ///
				7 "Worked without pay in own family-operated farm or business" ///
				8 "Carpenter" ///
				9 "Construction worker" ///
				10 "Driver (habal -habal,pedicab,tricycle)" ///
				11 "Entrepreneur/Own business" ///
				12 "Farmer" ///
				13 "Fisherman" ///
				14 "Laborer" ///
				15 "Welder" ///
				16 "OFW" ///
				17 "Works  in other family-operated farm or business" ///
				18 "Paintor" ///
				19 "Person with Disablities (PWD)" ///
				20 "Vendor" ///
				21 "Housewife" ///
				22 "Boat crew" ///
				23 "Charcoal maker" ///
				24 "Furniture maker" ///
				25 "Nipa maker" ///
				26 "Pensionner" ///
				27 "Electrician" ///
				28 "Bamboo woven mats maker" ///
				29 "Steel man" ///
				30 "Mechanic" ///
				31 "Handicraft maker" ///
				32 "Delivery man" ///
				33 "Scrap buyer" 
				
		lab val `var_name' `var_name'_lbl

		local var_name "L149"
			lab define ///
			`var_name'_lbl	///
				1 "In kind, not cash" ///
				2 "Per piece" ///
				3 "Per hour" ///
				4 "Per day" ///
				5 "Monthly" ///
				6 "Pakyaw" ///
				8 "Commission basis" ///
				8 "Weekly" ///
				9 "Per kilo" ///
				10 "Per head" ///
				11 "Per harvest" ///
				12 "Per passenger/Per person" ///
				13 "Every 3 months" ///
				14 "Every 15 days" ///
				16 "Quarterly" ///
				17 "Every 5 months" ///
				18 "Every 2 months" ///
				19 "Owner" ///
				20 "Every sack" ///
				99 "None" 
				
		lab val `var_name' `var_name'_lbl

		lab val L150 L152 L154 L156 yes_no

		local var_name "L153"
			lab define ///
			`var_name'_lbl	///
				1 "70,000 pesos or more" ///
				2 "50,000-69,999 pesos" ///
				3 "30,000-49,999 pesos" ///
				4 "15,000-29,999 pesos" ///
				5 "5,000-14,999 pesos" ///
				6 "less than 5,000 pesos" ///
				8 "No profit" ///
				9 "For personal consumption only" ///
				9999 "Don’t know" 

		lab val `var_name' L155 L157 `var_name'_lbl
		lab val Grid_L157_1_1L157_1 Grid_L157_1_2L157_1 Grid_L157_1_3L157_1 Grid_L157_1_4L157_1 Grid_L157_1_5L157_1 Grid_L157_1_6L157_1 Grid_L157_1_7L157_1 Grid_L157_1_9L157_1 yes_no
		lab val Grid_M158_1M158 Grid_M158_2M158 Grid_M158_3M158 Grid_M158_4M158 Grid_M158_5M158 Grid_M158_6M158 Grid_M158_7M158 Grid_M158_8M158 Grid_M158_9M158 Grid_M158_10M158 Grid_M158_11M158 Grid_M158_12M158 Grid_M158_13M158 Grid_M158_14M158 yes_no
		lab val Grid_M159_1M159 Grid_M159_2M159 Grid_M159_3M159 Grid_M159_4M159 Grid_M159_5M159 Grid_M159_6M159 Grid_M159_7M159 Grid_M159_9M159 yes_no
		lab val M160 Grid_M161_* yes_no

		local var_name "N162"
			lab define ///
			`var_name'_lbl	///
				1 "Strong materials (galvanized iron, aluminum, tile, concrete, brick stone, wood, asbestos)" ///
				2 "Light materials (cogon, nipa, anahaw)" ///
				3 "Salvaged/makeshift materials" ///
				4 "Mixed but predominantly strong materials" ///
				5 "Mixed but predominantly light materials" ///
				6 "Mixed but predominantly salvaged materials" 

		lab val `var_name' N163 `var_name'_lbl


		local var_name "N164"
			lab define ///
			`var_name'_lbl	///
				1 "Earth/ Sand" ///
				2 "RUDIMENTARY FLOOR" ///
				3 "Wood planks " ///
				4 "Palm/ Bamboo" ///
				5 "FINISHED FLOOR" ///
				6 "Parquet or polished wood " ///
				7 "Vinyl, linoleum " ///
				8 "Ceramic tiles" ///
				9 "Marble" ///
				10 "Cement and bamboo" ///
				11 "Plywood" ///
				12 "Cement and plywood" ///
				13 "Cement and coco lumber" ///
				14 "Coco lumber" ///
				15 "Cement and wood" ///
				16 "Wood" 

		lab val `var_name' `var_name'_lbl

		local var_name "N165"
			lab define ///
			`var_name'_lbl	///
				1 "Single house" ///
				2 "Duplex" ///
				3 "Apartment/Condominiums/Townhouse" ///
				4 "Commercial/Industrial/Agricultural building or house" ///
				5 "Other housing (cave, boat, under a bridge, etc)" 
		lab val `var_name' `var_name'_lbl


		local var_name "N167"
			lab define ///
			`var_name'_lbl	///
				1 "Own house and lot; or Owner-like possession of house and lot" ///
				2 "Rented house/room including lot" ///
				3 "Own house but rented lot" ///
				4 "Own house, rent-free lot with consent of owner" ///
				5 "Own house, rent-free lot without consent of owner" ///
				6 "Rent-free house and lot with consent of owner" ///
				7 "Rent-free house and lot without consent of owner" 
		lab val `var_name' `var_name'_lbl


		local var_name "N168"
			lab define ///
			`var_name'_lbl	///
				0 "No lighting " ///
				1 "Electricity" ///
				2 "Gas " ///
				3 "Paraffin lamp" ///
				4 "Firewood" ///
				5 "Candles " ///
				6 "Solar " ///
				7 "Generator" ///
				8 "Battery on motor" ///
				9 "Flashlight" 
		lab val `var_name' `var_name'_lbl


		local var_name "N169"
			lab define ///
			`var_name'_lbl	///
				0 " No food is cooked in household" ///
				1 " Electricity" ///
				2 " LPG" ///
				3 " Natural gas " ///
				4 " Biogas" ///
				5 " Kerosene " ///
				6 "Coal, Lignite " ///
				7 " Charcoal " ///
				8 " Wood" ///
				9 " Straw/Shrubs/Grass " ///
				10 " Agricultural crop " ///
				11 " Animal dung " ///
				12 " Butane" 
		lab val `var_name' `var_name'_lbl

		lab val Grid_N170_1N170 Grid_N170_2N170 Grid_N170_3N170 N172 yes_no

		local var_name "N171"
			lab define ///
			`var_name'_lbl	///
				1  "Telephone/mobile phone is in the house" ///
				2  "Less than 15 minutes" ///
				3  "15-30 minutes" ///
				4  "31-60 minutes" ///
				5  "More than an hour" ///
				6  "There is no telephone/mobile phone or do not use the telephone/mobile phone" 
		lab val `var_name' `var_name'_lbl

	label data "WASH Philippines IE endline raw dataset"
	save "$household/endline_raw_hh",replace

}	
