   * ******************************************************************** *
   * ******************************************************************** *
   *                                                                      *
   *               create panel dataset                      *
   *                                                                      *
   * ******************************************************************** *
   * ******************************************************************** *
   ** OUTLINE:      PART 0: merge baseline and endline data with treatment status
   ** IDS VAR:      hhid
   ** WRITTEN BY:   odbayar batmunkh
   ** Last date modified: 24 Nov 2020

*load baseline data
  use "$baseline_dtFin/baseline_hh.dta",clear

*add endline data
  append using "$endline_dtFin/endline_hh"

*add treatment status
  merge m:1 hhid using "$endline_dtFin/treatment_status2",nogen

*keeping only panel households
  egen max_survid=max(survid),by(hhid)
  egen min_survid=min(survid),by(hhid)

*drop barangays that were not in endline
  drop if max_survid==1
  drop max_survid min_survid temp_hh_head_age

*label some variables
  label define survid_lbl 1 "Baseline" 2 "Endline"
  label values survid survid_lbl
  label var count_under5 "Number children under 5 in hh"

**************************
*create new variables here
**************************
  *creating the ratio of children to diarrhea cases reported
  *this will be thought of as the probability of each child in that household having diarrhea
    foreach x of varlist illness_*{
      *recode `x' (.=0)
      gen r_`x'=`x'/count_under5
    }

  *land assets
    recode agri_asset_land_value (.=0) if survid == 1
    winsor2 agri_asset_land_value,cuts (0 99) replace
    gen ln_agri_asset_land_value=ln(agri_asset_land_value + 1)
  *external support
    recode external_support_25perasa external_support_50perasa (.=0) if survid == 2

    label var external_support_muni_brgy  "external_support_muni_brgy" 
    label var external_support_sl "external_support_sl" 
    label var external_support_kalahiprogram  "external_support_kalahiprogram" 
    label var external_support_25perasa "external_support_25perasa" 
    label var external_support_50perasa "external_support_50perasa"

  *household head income last 4 week
    recode hh_head_income_1m (97=0) (.=0)
    label var hh_head_income_1m "household head's income in last 4 weeks"

  *open defecation
  *recoding the change in open defecation variable
  *less is better
    recode reported_change_od (3=1) (2=-1) (1=0)
    label define change_od_lbl 1 "more od" 0 "no change"  -1 "less od"
    label values reported_change_od change_od_lbl

  *label reported open defecation
    label define reported_coverage_od_lbl 5 "All of us" 4 "Most of us" 3 "Some of us" 2 "Few of us" 1 "None of us"
    label values reported_coverage_od reported_coverage_od_lbl

  **************************************
  **open defecation change 4 week recall into 1 week recall 
  **************************************
    rename r_illness_3plusbowelmovements r_illness_3plusbowel
    rename r_illness_mucusbloodstool     r_illness_mucusblood
    **converting the endline values of diarrhea into 
    foreach x of varlist r_illness_*{
    gen double round_`x'=round(`x',.01)
    *setting conservative conversion, basically 1 value of 4 week can be linked to a range of 1 week ratios, we are choosing the largest 1 week value.
    gen `x'_alt_c=.
    replace `x'_alt_c=0 if round_`x'==0
    replace `x'_alt_c=0.01 if round_`x'==0.04
    replace `x'_alt_c=0.02 if round_`x'==0.08
    replace `x'_alt_c=0.03 if round_`x'==0.11
    replace `x'_alt_c=0.04 if round_`x'==0.15
    replace `x'_alt_c=0.05 if round_`x'==0.19
    replace `x'_alt_c=0.06 if round_`x'==0.22
    replace `x'_alt_c=0.07 if round_`x'==0.25
    replace `x'_alt_c=0.08 if round_`x'==0.28
    replace `x'_alt_c=0.09 if round_`x'==0.31
    replace `x'_alt_c=0.1 if round_`x'==0.33
    replace `x'_alt_c=0.1 if round_`x'==0.34
    replace `x'_alt_c=0.11 if round_`x'==0.37
    replace `x'_alt_c=0.12 if round_`x'==0.4
    replace `x'_alt_c=0.13 if round_`x'==0.43
    replace `x'_alt_c=0.14 if round_`x'==0.45
    replace `x'_alt_c=0.15 if round_`x'==0.48
    replace `x'_alt_c=0.16 if round_`x'==0.5
    replace `x'_alt_c=0.17 if round_`x'==0.53
    replace `x'_alt_c=0.18 if round_`x'==0.55
    replace `x'_alt_c=0.19 if round_`x'==0.57
    replace `x'_alt_c=0.2 if round_`x'==0.59
    replace `x'_alt_c=0.21 if round_`x'==0.61
    replace `x'_alt_c=0.22 if round_`x'==0.63
    replace `x'_alt_c=0.23 if round_`x'==0.65
    replace `x'_alt_c=0.24 if round_`x'==0.67
    replace `x'_alt_c=0.25 if round_`x'==0.68
    replace `x'_alt_c=0.26 if round_`x'==0.7
    replace `x'_alt_c=0.27 if round_`x'==0.72
    replace `x'_alt_c=0.28 if round_`x'==0.73
    replace `x'_alt_c=0.29 if round_`x'==0.75
    replace `x'_alt_c=0.3 if round_`x'==0.76
    replace `x'_alt_c=0.31 if round_`x'==0.77
    replace `x'_alt_c=0.32 if round_`x'==0.79
    replace `x'_alt_c=0.33 if round_`x'==0.8
    replace `x'_alt_c=0.34 if round_`x'==0.81
    replace `x'_alt_c=0.35 if round_`x'==0.82
    replace `x'_alt_c=0.36 if round_`x'==0.83
    replace `x'_alt_c=0.37 if round_`x'==0.84
    replace `x'_alt_c=0.38 if round_`x'==0.85
    replace `x'_alt_c=0.39 if round_`x'==0.86
    replace `x'_alt_c=0.4 if round_`x'==0.87
    replace `x'_alt_c=0.41 if round_`x'==0.88
    replace `x'_alt_c=0.42 if round_`x'==0.89
    replace `x'_alt_c=0.43 if round_`x'==0.89
    replace `x'_alt_c=0.44 if round_`x'==0.9
    replace `x'_alt_c=0.45 if round_`x'==0.91
    replace `x'_alt_c=0.46 if round_`x'==0.91
    replace `x'_alt_c=0.47 if round_`x'==0.92
    replace `x'_alt_c=0.48 if round_`x'==0.93
    replace `x'_alt_c=0.49 if round_`x'==0.93
    replace `x'_alt_c=0.5 if round_`x'==0.94
    replace `x'_alt_c=0.51 if round_`x'==0.94
    replace `x'_alt_c=0.52 if round_`x'==0.95
    replace `x'_alt_c=0.53 if round_`x'==0.95
    replace `x'_alt_c=0.54 if round_`x'==0.96
    replace `x'_alt_c=0.55 if round_`x'==0.96
    replace `x'_alt_c=0.56 if round_`x'==0.96
    replace `x'_alt_c=0.57 if round_`x'==0.97
    replace `x'_alt_c=0.58 if round_`x'==0.97
    replace `x'_alt_c=0.59 if round_`x'==0.97
    replace `x'_alt_c=0.6 if round_`x'==0.97
    replace `x'_alt_c=0.61 if round_`x'==0.98
    replace `x'_alt_c=0.62 if round_`x'==0.98
    replace `x'_alt_c=0.63 if round_`x'==0.98
    replace `x'_alt_c=0.64 if round_`x'==0.98
    replace `x'_alt_c=0.65 if round_`x'==0.98
    replace `x'_alt_c=0.66 if round_`x'==0.99
    replace `x'_alt_c=0.67 if round_`x'==0.99
    replace `x'_alt_c=0.68 if round_`x'==0.99
    replace `x'_alt_c=0.69 if round_`x'==0.99
    replace `x'_alt_c=0.7 if round_`x'==0.99
    replace `x'_alt_c=0.71 if round_`x'==0.99
    replace `x'_alt_c=0.72 if round_`x'==0.99
    replace `x'_alt_c=0.73 if round_`x'==0.99
    replace `x'_alt_c=0.74 if round_`x'==1

    *setting conservative conversion, basically 1 value of 4 week can be linked to a range of 1 week ratios, we are choosing the smallest 1 week value.
    *setting aggressive conversion
    gen double `x'_alt_a=.
    replace `x'_alt_a=0 if round_`x'==0
    replace `x'_alt_a=0.01 if round_`x'==0.04
    replace `x'_alt_a=0.02 if round_`x'==0.08
    replace `x'_alt_a=0.03 if round_`x'==0.11
    replace `x'_alt_a=0.04 if round_`x'==0.15
    replace `x'_alt_a=0.05 if round_`x'==0.19
    replace `x'_alt_a=0.06 if round_`x'==0.22
    replace `x'_alt_a=0.07 if round_`x'==0.25
    replace `x'_alt_a=0.08 if round_`x'==0.28
    replace `x'_alt_a=0.09 if round_`x'==0.31
    replace `x'_alt_a=0.1 if round_`x'==0.33
    replace `x'_alt_a=0.1 if round_`x'==0.34
    replace `x'_alt_a=0.11 if round_`x'==0.37
    replace `x'_alt_a=0.12 if round_`x'==0.4
    replace `x'_alt_a=0.13 if round_`x'==0.43
    replace `x'_alt_a=0.14 if round_`x'==0.45
    replace `x'_alt_a=0.15 if round_`x'==0.48
    replace `x'_alt_a=0.16 if round_`x'==0.5
    replace `x'_alt_a=0.17 if round_`x'==0.53
    replace `x'_alt_a=0.18 if round_`x'==0.55
    replace `x'_alt_a=0.19 if round_`x'==0.57
    replace `x'_alt_a=0.2 if round_`x'==0.59
    replace `x'_alt_a=0.21 if round_`x'==0.61
    replace `x'_alt_a=0.22 if round_`x'==0.63
    replace `x'_alt_a=0.23 if round_`x'==0.65
    replace `x'_alt_a=0.24 if round_`x'==0.67
    replace `x'_alt_a=0.25 if round_`x'==0.68
    replace `x'_alt_a=0.26 if round_`x'==0.7
    replace `x'_alt_a=0.27 if round_`x'==0.72
    replace `x'_alt_a=0.28 if round_`x'==0.73
    replace `x'_alt_a=0.29 if round_`x'==0.75
    replace `x'_alt_a=0.3 if round_`x'==0.76
    replace `x'_alt_a=0.31 if round_`x'==0.77
    replace `x'_alt_a=0.32 if round_`x'==0.79
    replace `x'_alt_a=0.33 if round_`x'==0.8
    replace `x'_alt_a=0.34 if round_`x'==0.81
    replace `x'_alt_a=0.35 if round_`x'==0.82
    replace `x'_alt_a=0.36 if round_`x'==0.83
    replace `x'_alt_a=0.37 if round_`x'==0.84
    replace `x'_alt_a=0.38 if round_`x'==0.85
    replace `x'_alt_a=0.39 if round_`x'==0.86
    replace `x'_alt_a=0.4 if round_`x'==0.87
    replace `x'_alt_a=0.41 if round_`x'==0.88
    replace `x'_alt_a=0.42 if round_`x'==0.89
    replace `x'_alt_a=0.44 if round_`x'==0.9
    replace `x'_alt_a=0.45 if round_`x'==0.91
    replace `x'_alt_a=0.47 if round_`x'==0.92
    replace `x'_alt_a=0.48 if round_`x'==0.93
    replace `x'_alt_a=0.5 if round_`x'==0.94
    replace `x'_alt_a=0.52 if round_`x'==0.95
    replace `x'_alt_a=0.54 if round_`x'==0.96
    replace `x'_alt_a=0.57 if round_`x'==0.97
    replace `x'_alt_a=0.61 if round_`x'==0.98
    replace `x'_alt_a=0.66 if round_`x'==0.99
    replace `x'_alt_a=0.74 if round_`x'==1

    *setting baseline values to be same as before, without conversion
    replace `x'_alt_c=`x' if survid==1
    replace `x'_alt_a=`x' if survid==1
    }

  ************************
  *labeling type of toilet
  ************************
    #delimit ;
    label define toilet_type_label 
    0 "No facility/Bush/Field"
    1 "Flush to sewer"
    2 "Flush to septic tank"
    3 "Flush to pit toilet"
    4 "Flush to elsewhere"
    5 "Flush to don't know where"
    6 "Ventilated pit toilet"
    7 "Pit toilet with slab"
    8 "Pit toilet without slab/open pit"
    9 "Composting toilet"
    10 "Bucket toilet"
    11 "Drop type/Overhang type"
    12 "Public Toilet"
    96 "Other"
    ;
    #delimit cr
    label values toilet_type toilet_type_label
    tab toilet_type survid

  *set panel
  xtset hhid survid

  *generating types of toilet the household has: 
    levelsof toilet_type,local(toilet_types)
    foreach x of local toilet_types{
      gen toilet_type_`x'=toilet_type==`x'
      gen change_`x'=d.toilet_type_`x'
    }

  *******************
  *change in toilet type variables
  *******************
    **grouping households into those that adopted toilets or adopted better toilets, these are not exactly related to JMPSan
    gen temp_adopted_flush=inlist(toilet_type,1,2,3,4,5) & !inlist(d.toilet_type,1,2,3,4,5)
    egen adopted_flush=max(temp_adopted_flush),by(hhid)

    gen temp_adopted_pit=inlist(toilet_type,6,7,8,9) & !inlist(d.toilet_type,6,7,8,9)
    egen adopted_pit=max(temp_adopted_pit),by(hhid)

    gen temp_stayed_flush= inlist(toilet_type,1,2,3,4,5) & inlist(d.toilet_type,1,2,3,4,5)
    egen stayed_flush=max(temp_stayed_flush),by(hhid)

    gen temp_stayed_pit= inlist(toilet_type,6,7,8,9) & inlist(d.toilet_type,6,7,8,9)
    egen stayed_pit=max(temp_stayed_pit),by(hhid)

    gen temp_regressed= inlist(toilet_type,0,10,11,12,96) & inlist(d.toilet_type,0,1,2,3,4,5,6,7,8,9,10,11,12,96) 
    egen regressed=max(temp_regressed),by(hhid)

    drop temp_*

    label var adopted_flush "household adopted flush toilets"
    label var adopted_pit "household adopted pit toilets"
    label var stayed_flush "household stayed with flush toilets, maybe change type of flush"
    label var stayed_pit "household stayed with pit toilets, maybe change type of pit"
    label var regressed "household either regressed in toilet type or didn't change from unsanitary outcomes"

  *tabulate change 
    tabstat adopted_flush adopted_pit stayed_flush stayed_pit regressed if survid == 2

  ***************************
  *creating adoption variable
  ***************************
    gen adoption=.

    local counter=1
    foreach x of varlist adopted_flush adopted_pit stayed_flush stayed_pit regressed{
      replace adoption=`counter' if `x'==1
      local ++counter
    }

    label define adoption_label 1 "adopted flush" 2 "adopted pit" 3 "stayed flush" 4 "stayed pit" 5 "regressed or still bad"
    label values adoption adoption_label
    tab adoption if survid == 2

  *creating variable for adoption any flush or pit toilet
    gen adopted_any=adopted_flush==1 | adopted_pit==1
    label var adopted_any "household adopted pit or flush toilet"

  ***************************
  *creating new toilet type index 
  ***************************
    gen toilet_index=.
    replace toilet_index=2 if inlist(toilet_type,1,2,3,4,5)
    replace toilet_index=1 if inlist(toilet_type,6,7,8,9)
    replace toilet_index=0 if inlist(toilet_type,0,10,11,12,96)
    label var toilet_index "toilet index"
    label define toilet_index_label 0 "No toilet" 1 "Pit toilet" 2 "Flush toilet" 
    label val toilet_index toilet_index_label
    tab toilet_index survid

  ***************************************************************
  **replacing household head characteristics with endline values - for sake of consistency
  ***************************************************************
    preserve
      keep if survid==2
      keep hhid hh_head*
      tempfile hh_info
      save `hh_info'
    restore
    drop hh_head* // drops baseline hh head characteristics
    merge m:1 hhid using `hh_info',nogen

  *testing to see if same households who had children under at at endline do differently
    gen has_child_under5=count_under5!=0
    tab has_child_under5 survid // share of sample with children under 5 drops at endline

  *************************************************
  *setting treatment variable and comparison groups
  *************************************************
    local trt_vars "bcc_hardware bcc_mfi bcc_bigmfi "
    foreach x of local trt_vars{
      gen `x'=treatment
    }

    *limiting comparison groups
    recode bcc_hardware (3=.) (4=.) (2=1) (1=0)
    recode bcc_mfi      (2=.) (4=.) (3=1) (1=0)
    recode bcc_bigmfi   (2=.) (3=.) (4=1) (1=0)

    tab bcc_hardware treatment if survid == 2
    tab bcc_mfi treatment if survid == 2
    tab bcc_bigmfi treatment if survid == 2

  **create municipality dummies
    levelsof citymunicipality,local(muni)
    local y=1
    foreach x of local muni{
      gen muni_`y'=citymunicipality=="`x'"
      local ++y
    }

  ************************************
  *generating exernal support variable
  ************************************
    gen hardware=external_support_sl==1 | external_support_muni_brgy==1 | external_support_kalahiprogram==1 
    label var hardware "Household received external hardware support"

    tab hardware survid

  *******************************
  *redoing the toilet index based on Claire's suggestions
  *******************************
    drop toilet_index
    gen toilet_index=0 if inlist(toilet_type,0,10,11,12,96)
    replace toilet_index=1 if inlist(toilet_type,4,5,8)
    replace toilet_index=2 if inlist(toilet_type,6,7,9)
    replace toilet_index=3 if inlist(toilet_type,1,2,3)

    label define toilet_index_lab 0 "No toilet" 1 "Pit toilet" 2 "Improved Pit toilet" 3 "Flush toilet"
    label values toilet_index toilet_index_lab
    tab toilet_index survid

  
  *****************************************************************
  **checking if toilet quality is better for each source of support
  *****************************************************************
    egen count_sources=rsum(external_support_*)
    gen source_type=.
    local counter=1

    foreach x of varlist external_support_muni_brgy-external_support_50perasa{
      replace source_type=`counter' if `x'==1 & count_sources==1
      local ++counter
    }
    replace source_type=0 if treatment==1 & hardware==0 & external_support_25perasa==0 & external_support_50perasa==0 & survid==2
    **redoing the source of support again for report 5/28/2019
    recode source_type (3=1) (2=1)
    replace source_type=1 if hardware==1 & external_support_25perasa==0 & external_support_50perasa==0

    label define sources_label 1 "Any Hardware Subsidy" 4 "25% MFI" 5 "50% MFI" 0 "No Support in BCC arm" 
    label values source_type sources_label
    label var source_type "Support source , no overlaps"

    tab source_type survid,mi
    
  *grant used for other purposes?
    egen pppp_used_for_other=rsum(pppp_used_for_5 pppp_used_for_6 pppp_used_for_7 pppp_used_for_8 pppp_used_for_9 pppp_used_for_10 pppp_used_for_11 pppp_used_for_12 pppp_used_for_13 pppp_used_for_14 pppp_used_for_15 pppp_used_for_16 pppp_used_for_17 pppp_used_for_18 pppp_used_for_19 pppp_used_for_20 pppp_used_for_21)
    replace pppp_used_for_other=1 if pppp_used_for_other>1 & pppp_used_for_other!=.

  ********************
  **labeling variables
  ********************
    label var counthh_members               "Household Size" 
    label var count_worker                  "\# Working age household members" 
    label var count_adult                   "\# Adult household members" 
    label var hhchar_num_bedrooms           "Number of bedrooms" 
    label var hhchar_own_house              "Household Owns the house" 
    label var hhchar_rent_house             "Household Rents the house" 
    label var hh_income_source_remittances  "Household has remittances" 
    label var hh_income_source_salary       "Household has salary income" 
    label var agri_asset_agri_land          "Household has agricultural land" 
    label var agri_asset_land_area          "Agricultural land area m2" 
    label var agri_asset_land_value         "Agricultural land value PHP" 
    label var toilet_has_hw_station         "Toilet has handwashing station" 
    label var satisfaction_toilet           "Reported Toilet Satisfaction" 
    label var toilet_under_construction     "Toilet is under construction" 
    label var jmpsan                        "Binary for JMPSan indicator" 
    label var jmpwater                      "Binary for JMPWater indicator"
    label var toilet_index                  "Toilet quality index"
    label var count_under5                  "Number of children under 5 years old"
    label var ln_agri_asset_land_value      "Natural log: Value agricultural land"
    label var constraint_credit             "Contraint to toilet improvement: credit"
    label var constraint_hardware           "Contraint to toilet improvement: hardware"
    label var illness_diarrhea              "Child diarrhea"
    label var pppp_used_for_other           "4P grant used for Other purposes"
    label var survid                        "Time variable"

  ************************************
  *constraints to adoption of latrines
  ************************************
    #delimit ;
    label define constraint_label

    1 "High financial cost"
    2 "Competing priorities"
    3 "Labor constraint"
    4 "Materials constraint"
    5 "Geological limitations"
    6 "Limited space"
    7 "Tenancy issues"
    8 "Dislike toilet options"
    9 "No constraints"
    ;
    #delimit cr
    drop reported_constraint
    destring reported_constraint*,replace
    label values reported_constraint*  constraint_label
    
    tab reported_constraint1 survid
    tab reported_constraint2 survid
    tab reported_constraint3 survid

  ************************************
  *more constraints
  ************************************
    forvalues x = 1(1)9{
      gen constraint_is_`x'= reported_constraint1==`x' | reported_constraint2==`x' | reported_constraint3==`x' 
    }
    label var constraint_is_1 "High financial cost"
    label var constraint_is_2 "Competing priorities"
    label var constraint_is_3 "Labor constraint"
    label var constraint_is_4 "Materials constraint"
    label var constraint_is_5 "Geological limitations"
    label var constraint_is_6 "Limited space"
    label var constraint_is_7 "Tenancy issues"
    label var constraint_is_8 "Dislike toilet options"
    label var constraint_is_9 "No constraints"

  *agricultural assets
    recode agri_asset_land_area agri_asset_land_value (999997=0) (999999=0)

  *new time variable - used in making interaction variables
    gen after=0
    replace after=1 if survid==2
    label var after "Time variable"

  *label more variables
    label var bcc_hardware  "Treatment"
    label var bcc_mfi  "Treatment"
    label var bcc_bigmfi "Treatment"
    label var external_support_muni_brgy  "Hardware subsidy Muni/Brgy"
    label var external_support_sl         "Hardware subsidy SLP"
    label var external_support_kalahiprogram "Hardware subsidy Kalahi Sidds"
    recode external_support_muni_brgy external_support_sl external_support_kalahiprogram (.=0)
    label var reported_programs_sanitation "HH remembers sanitation program"
    label var count_under5 "# children under 5"

  *more variable generation and fixes
    egen max_hardware=max(hardware),by(hhid)
    label var max_hardware "household received hardware support at endline"
    
    recode loan_amount (.=0) // if no loans mentioned set to 0
    gen toilet_important = perception_importance_toilet==5
    gen attend_fds= inrange(advice_attend_fds,1,2)
    gen attend_clts=advice_familiar_clts==1
    gen attend_asa=advice_familiar_asa==1
    gen attend_s4p=advice_familiar_s4p==1
    gen toilet_recommend=recommend==5
    label var toilet_recommend "very likely to recommend toilet construction to other households"

    recode has_asa_loan(2 .=0)
    gen no_support=hardware==0 & has_asa_loan!=1
  
    replace no_support=. if survid==1
    egen max_no_support=max(no_support),by(hhid)
    label var max_no_support "household never got support for latrine construction"
    tab max_no_support treatment if survid == 2

  *rename some variables
    rename toilet_feat_raisedplatform      tf_raisedplatform
    rename toilet_feat_footrests           tf_footrests
    rename toilet_feat_seat                tf_seat
    rename toilet_feat_floortilesconcrete  tf_floortilesconcrete
    rename toilet_feat_fullyenclosedwall   tf_fullyenclosedwall
    rename toilet_feat_partenclosedwall    tf_partenclosedwall
    rename toilet_feat_fullycoveredroof    tf_fullycoveredroof
    rename toilet_feat_partcoveredroof     tf_partcoveredroof
    rename toilet_feat_door                tf_door
    rename toilet_feat_waterseal           tf_waterseal
  
  *checking for overlaps between treatments
    egen overlaps= rsum(external_support_muni_brgy external_support_sl external_support_kalahiprogram) 
    gen temp_overlaps=overlaps>=1
    gen overlap_hw_mfi=temp_overlaps+toilet_loan_any
    recode overlap_hw_mfi (1=0) (2=1)
    tab overlap_hw_mfi survid // 105 households got overlapping support at endline from both hardware and mfi

    gen overlap=0
    replace overlap=1 if overlaps==1 & toilet_loan_any==0
    replace overlap=2 if overlaps>1  & toilet_loan_any==0
    replace overlap=3 if overlaps==0 & toilet_loan_any==1
    replace overlap=4 if overlaps>=1 & toilet_loan_any==1

    label define overlap_label 0 "No support" 1 "Single External Hardware" 2 "Overlap External Hardware" 3 "Single Loan" 4 "Overlap Loan and Hardware"
    label values overlap overlap_label
    
    tab overlap survid

  *generating new variable for community coverage of improve sanitation
    gen is_jmpsan=jmpsan==1
    egen brgy_jmpsan=sum(is_jmpsan),by(survid nscbbgycode)
    gen is_hh=1
    egen brgy_hh=sum(is_hh),by(survid nscbbgycode)
    gen community_jmpsan=brgy_jmpsan/brgy_hh

  *more variables
    gen satisfaction_toilet_pr=satisfaction_toilet==4 
    gen toilet_index_pr=toilet_index==3 
    gen reported_coverage_od_pr=reported_coverage_od==1  
    gen observed_od=inlist(toilet_type,0,12,96)
    egen new_toilet_index=rsum(tf_raisedplatform tf_footrests tf_seat tf_floortilesconcrete tf_fullyenclosedwall tf_partenclosedwall tf_fullycoveredroof tf_partcoveredroof tf_door tf_waterseal)

  *label variables
    label var satisfaction_toilet_pr "HH is Very Satisfied with toilet"
    label var toilet_index_pr "HH has flush toilet"
    label var reported_coverage_od_pr "No one in HH does OD"
    label var community_jmpsan "Community Coverage of Improved Sanitation"
    label var jmpsan "Improved Sanitation"
    label var toilet_index "Toilet Quality Index"
    label var toilet_loan_any "HH Has Loan for Latrine Improvements"
    label var constraint_credit "Constraint is Credit" 
    label var constraint_hardware "Constraint is Hardware" 
    label var reported_coverage_od "Share of HH practicing OD"
    label var hh_head_age "HH head's age"
    label var hh_head_gender "HH head's sex"
    label var hh_head_educ "HH head's education"
    label var toilet_repair_or_built "HH built or upgraded latrine"
    label var toilet_loan_any        "HH took out loan for latrine upgrades"
    label var r_illness_diarrhea_alt_c "Converted Diarrhea Ratio"
    label var overlap_hw_mfi "household has both hardware and loan support"
    label var new_toilet_index "toilet features index, highest - more features like raised platform etc"

  *latine has both soap and water for handwashing
    gen toilet_has_soap_and_water=toilet_has_hw_soap_water == 3
    label var toilet_has_soap_and_water "Latrine features: Soap and Water"

  *familiarity questions yes/no change
    recode advice_familiar_* (2=0)

  *****************
  *save final panel dataset
  *****************
    save "$household/panel_clean",replace
